
clear
macro drop _all
program drop _all
set more off
set linesize 80

capture log close
log using "X:\Schwartz\Graf_Schwartz\DemResearchdraft\do_log files\graph_bystate_ny.log",replace

set mem 100m



clear
set mem 100m


***************************************************
* WESTERN AND NEW ENGLAND STATES + NEW YORK STATE *
***************************************************



***ODDS OF RACE/ETHNIC ENDOGAMY FROM MLOGIT****


**These are the exponential multinomial logit coefficients
**(source:models_bystate_ny.log).
**To get the odds I have to multiply the coefficients in obs 1-3
**by the odds for married couples (the omitted category in the
**mlogit. The odds of homogamy for married couples come from
**the log linear models (source: baseline.log).

**These odds ratios can be found in the output "by year"

input rel_var beta_ml1990 beta_ml2000
1 .335 .357
2 .329 .360
3 .553 .569
4 1 1

end



*multiply the odds ratios by the baseline odds for married couples.
gen h1990 = beta_ml1990* 22.54563
gen h2000 = beta_ml2000* 20.25763


list

#delimit ;

cd "X:\Schwartz\Graf_Schwartz\DemResearchdraft\graphs" ;


****black and white*** ;

graph bar (asis) h1990 h2000,  over(rel_var, relabel(1 `" "Same-Sex" "Male Couples" "' 2 `" "Same-Sex" "Female Couples" "'
                                             3 `" "Different-Sex" "Cohabiting Couples" "' 4 `" "Different-Sex" "Married Couples" "' )
         label(labsize(*1.0)) gap(120))
         nofill exclude0 yscale(r(1 25) log) ylabel(5(5)25, grid)
         bar(1, bcolor(gs4) blcolor(black))  bar(2, bcolor(gs10) blcolor(black))
         scheme(s1color)
         graphregion(fcolor(gs16)) plotregion(style(none))
         ytitle("Odds")
         legend(order(1 2) label(1 "1990") label(2 "2000") size(*.95)) outergap(80) ;


    graph export graph_bystate_ny_1.wmf, replace fontface(garamond) ;



clear ;
set mem 100m ;


#delimit cr

***ABS(AGE DIFF) FROM MLOGIT****


**These are the exponential multinomial logit coefficients.
**To get the odds I have to multiply the coefficients in obs 1-3
**by the odds for married couples (the omitted category in the
**mlogit. The odds of homogamy for married couples come from
**the unadjusted log linear models (same as graphed above).

input rel_var beta_ml1990 beta_ml2000
1 1.118 1.139
2 1.077 1.161
3 1.098 1.081
4 1  1

end


gen h1990 = beta_ml1990*.7834288
gen h2000 = beta_ml2000*.7881284


#delimit ;


****black and white*** ;

graph bar (asis) h1990 h2000,  over(rel_var, relabel(1 `" "Same-Sex" "Male Couples" "' 2 `" "Same-Sex" "Female Couples" "'
                                             3 `" "Different-Sex" "Cohabiting Couples" "' 4 `" "Different-Sex" "Married Couples" "' )
         label(labsize(*1.0)) gap(120))
         nofill yscale(r(0.75 1.00) log) ylabel(0.75(.05)1.00, grid labsize(*1.0))  exclude0
         bar(1, bcolor(gs4) blcolor(black))  bar(2, bcolor(gs10) blcolor(black))
         scheme(s1color)
         graphregion(fcolor(gs16)) plotregion(style(none))
         ytitle("Odds")
         legend(order(1 2) label(1 "1990") label(2 "2000") size(*.95)) outergap(80) ;



    graph export graph_bystate_ny_2.wmf, replace fontface(garamond) ;


clear ;
set mem 100m ;


#delimit cr

input rel_var bdc2_90 bdc3_90 bdc4_90 bdc2_00 bdc3_00 bdc4_00
1  .757  .875  1.582  1.247  .838 1.420
2  .527  .930  1.314  1.144 1.157  .962
3  1.239 1.015 1.058  1.248 1.058 1.015
4 1 1 1 1 1 1

end

gen dc2_90 = bdc2_90*0.3619808
gen dc3_90 = bdc3_90*0.4571998
gen dc4_90 = bdc4_90*0.3336757

gen dc2_00 = bdc2_00*.323386
gen dc3_00 = bdc3_00*.4352551
gen dc4_00 = bdc4_00*.3131675


gen dc24_00 = dc2_00*dc3_00*dc4_00
gen dc34_00 = dc3_00*dc4_00

gen dc24_90 = dc2_90*dc3_90*dc4_90
gen dc34_90 = dc3_90*dc4_90



#delimit ;

****black and white*** ;

graph bar (asis) dc24_90 dc24_00,  over(rel_var, relabel(1 `" "Same-Sex" "Male Couples" "' 2 `" "Same-Sex" "Female Couples" "'
                                             3 `" "Different-Sex" "Cohabiting Couples" "' 4 `" "Different-Sex" "Married Couples" "' )
         label(labsize(*1.0)) gap(120))
         nofill exclude0 yscale(r(.03 .3) log) ylabel(.05 .1 .2 .3, grid)
         bar(1, bcolor(gs4) blcolor(black))  bar(2, bcolor(gs10) blcolor(black))
         scheme(s1color)
         graphregion(fcolor(gs16)) plotregion(style(none))
         ytitle("Odds")
         legend(order(1 2) label(1 "1990") label(2 "2000") size(*.95)) outergap(80) ;



    graph export graph_bystate_ny_3.wmf, replace fontface(garamond) ;


****black and white*** ;

graph bar (asis) dc34_90 dc34_00,  over(rel_var, relabel(1 `" "Same-Sex" "Male Couples" "' 2 `" "Same-Sex" "Female Couples" "'
                                             3 `" "Different-Sex" "Cohabiting Couples" "' 4 `" "Different-Sex" "Married Couples" "' )
         label(labsize(*1.0)) gap(120))
         nofill exclude0 yscale(r(.03 .3) log) ylabel(.05 .1 .2 .3, grid)
         bar(1, bcolor(gs4) blcolor(black))  bar(2, bcolor(gs10) blcolor(black))
         scheme(s1color)
         graphregion(fcolor(gs16)) plotregion(style(none))
         ytitle("Odds")
         legend(order(1 2) label(1 "1990") label(2 "2000") size(*.95)) outergap(80) ;



    graph export graph_bystate_ny_4.wmf, replace fontface(garamond) ;


#delimit cr


****************
* OTHER STATES *
****************


clear

***ODDS OF RACE/ETHNIC ENDOGAMY FROM MLOGIT****


**These are the exponential multinomial logit coefficients
**(source:models_bystate_ny.log).
**To get the odds I have to multiply the coefficients in obs 1-3
**by the odds for married couples (the omitted category in the
**mlogit. The odds of homogamy for married couples come from
**the log linear models (source: baseline.log).

**These odds ratios can be found in the output "by year"

input rel_var beta_ml1990 beta_ml2000
1 .278 .302
2 .455 .426
3 .534 .564
4 1 1

end



*multiply the odds ratios by the baseline odds for married couples.
gen h1990 = beta_ml1990* 22.54563
gen h2000 = beta_ml2000* 20.25763


list

#delimit ;

cd "X:\Schwartz\Graf_Schwartz\DemResearchdraft\graphs" ;


****black and white*** ;

graph bar (asis) h1990 h2000,  over(rel_var, relabel(1 `" "Same-Sex" "Male Couples" "' 2 `" "Same-Sex" "Female Couples" "'
                                             3 `" "Different-Sex" "Cohabiting Couples" "' 4 `" "Different-Sex" "Married Couples" "' )
         label(labsize(*1.0)) gap(120))
         nofill exclude0 yscale(r(1 25) log) ylabel(5(5)25, grid)
         bar(1, bcolor(gs4) blcolor(black))  bar(2, bcolor(gs10) blcolor(black))
         scheme(s1color)
         graphregion(fcolor(gs16)) plotregion(style(none))
         ytitle("Odds")
         legend(order(1 2) label(1 "1990") label(2 "2000") size(*.95)) outergap(80) ;


    graph export graph_bystate_ny_5.wmf, replace fontface(garamond) ;



clear ;
set mem 100m ;


#delimit cr

***ABS(AGE DIFF) FROM MLOGIT****


**These are the exponential multinomial logit coefficients.
**To get the odds I have to multiply the coefficients in obs 1-3
**by the odds for married couples (the omitted category in the
**mlogit. The odds of homogamy for married couples come from
**the unadjusted log linear models (same as graphed above).

input rel_var beta_ml1990 beta_ml2000
1 1.177 1.148
2 1.123 1.142
3 1.116 1.083
4 1  1



end


gen h1990 = beta_ml1990*.7834288
gen h2000 = beta_ml2000*.7881284


#delimit ;


****black and white*** ;

graph bar (asis) h1990 h2000,  over(rel_var, relabel(1 `" "Same-Sex" "Male Couples" "' 2 `" "Same-Sex" "Female Couples" "'
                                             3 `" "Different-Sex" "Cohabiting Couples" "' 4 `" "Different-Sex" "Married Couples" "' )
         label(labsize(*1.0)) gap(120))
         nofill yscale(r(0.75 1.00) log) ylabel(0.75(.05)1.00, grid labsize(*1.0))  exclude0
         bar(1, bcolor(gs4) blcolor(black))  bar(2, bcolor(gs10) blcolor(black))
         scheme(s1color)
         graphregion(fcolor(gs16)) plotregion(style(none))
         ytitle("Odds")
         legend(order(1 2) label(1 "1990") label(2 "2000") size(*.95)) outergap(80) ;



    graph export graph_bystate_ny_6.wmf, replace fontface(garamond) ;


clear ;
set mem 100m ;


#delimit cr

input rel_var bdc2_90 bdc3_90 bdc4_90 bdc2_00 bdc3_00 bdc4_00
1  .758  1.243 1.329  .9284 1.069 1.369
2  1.208 1.131 1.240  1.452 .965  1.190
3  1.277 1.038 1.059  1.305 1.041 1.087
4 1 1 1 1 1 1



end

gen dc2_90 = bdc2_90*0.3619808
gen dc3_90 = bdc3_90*0.4571998
gen dc4_90 = bdc4_90*0.3336757

gen dc2_00 = bdc2_00*.323386
gen dc3_00 = bdc3_00*.4352551
gen dc4_00 = bdc4_00*.3131675


gen dc24_00 = dc2_00*dc3_00*dc4_00
gen dc34_00 = dc3_00*dc4_00

gen dc24_90 = dc2_90*dc3_90*dc4_90
gen dc34_90 = dc3_90*dc4_90



#delimit ;

****black and white*** ;

graph bar (asis) dc24_90 dc24_00,  over(rel_var, relabel(1 `" "Same-Sex" "Male Couples" "' 2 `" "Same-Sex" "Female Couples" "'
                                             3 `" "Different-Sex" "Cohabiting Couples" "' 4 `" "Different-Sex" "Married Couples" "' )
         label(labsize(*1.0)) gap(120))
         nofill exclude0 yscale(r(.03 .3) log) ylabel(.05 .1 .2 .3, grid)
         bar(1, bcolor(gs4) blcolor(black))  bar(2, bcolor(gs10) blcolor(black))
         scheme(s1color)
         graphregion(fcolor(gs16)) plotregion(style(none))
         ytitle("Odds")
         legend(order(1 2) label(1 "1990") label(2 "2000") size(*.95)) outergap(80) ;



    graph export graph_bystate_ny_7.wmf, replace fontface(garamond) ;


****black and white*** ;

graph bar (asis) dc34_90 dc34_00,  over(rel_var, relabel(1 `" "Same-Sex" "Male Couples" "' 2 `" "Same-Sex" "Female Couples" "'
                                             3 `" "Different-Sex" "Cohabiting Couples" "' 4 `" "Different-Sex" "Married Couples" "' )
         label(labsize(*1.0)) gap(120))
         nofill exclude0 yscale(r(.03 .3) log) ylabel(.05 .1 .2 .3, grid)
         bar(1, bcolor(gs4) blcolor(black))  bar(2, bcolor(gs10) blcolor(black))
         scheme(s1color)
         graphregion(fcolor(gs16)) plotregion(style(none))
         ytitle("Odds")
         legend(order(1 2) label(1 "1990") label(2 "2000") size(*.95)) outergap(80) ;



    graph export graph_bystate_ny_8.wmf, replace fontface(garamond) ;




