
clear
macro drop _all
program drop _all
set more off
set linesize 80

capture log close
log using "X:\Schwartz\Graf_Schwartz\DemResearchdraft\do_log files\graph_bystate_ny_20to49.log",replace

set mem 100m



clear
set mem 100m


***************************************************
* WESTERN AND NEW ENGLAND STATES + NEW YORK STATE *
***************************************************



***ODDS OF RACE/ETHNIC ENDOGAMY FROM MLOGIT****


**These are the exponential multinomial logit coefficients
**(source:models_bystate_ny_20to49.log).
**To get the odds I have to multiply the coefficients in obs 1-3
**by the odds for married couples (the omitted category in the
**mlogit. The odds of homogamy for married couples come from
**the log linear models (source: baseline.log).

**These odds ratios can be found in the output "by year"

input rel_var beta_ml1990 beta_ml2000
1 .250 .285
2 .412 .438
3 .553 .539
4 1 1

end



*multiply the odds ratios by the baseline odds for married couples.
gen h1990 = beta_ml1990* 22.54563
gen h2000 = beta_ml2000* 20.25763


list

#delimit ;

cd "X:\Schwartz\Graf_Schwartz\DemResearchdraft\graphs" ;


****black and white*** ;

graph bar (asis) h1990 h2000,  over(rel_var, relabel(1 `" "Same-Sex" "Male Couples" "' 2 `" "Same-Sex" "Female Couples" "'
                                             3 `" "Different-Sex" "Cohabiting Couples" "' 4 `" "Different-Sex" "Married Couples" "' )
         label(labsize(*1.0)) gap(120))
         nofill exclude0 yscale(r(1 25) log) ylabel(5(5)25, grid)
         bar(1, bcolor(gs4) blcolor(black))  bar(2, bcolor(gs10) blcolor(black))
         scheme(s1color)
         graphregion(fcolor(gs16)) plotregion(style(none))
         ytitle("Odds")
         legend(order(1 2) label(1 "1990") label(2 "2000") size(*.95)) outergap(80) ;


    graph export graph_bystate_ny_20to49_1.wmf, replace fontface(garamond) ;



clear ;
set mem 100m ;


#delimit cr

***ABS(AGE DIFF) FROM MLOGIT****


**These are the exponential multinomial logit coefficients.
**To get the odds I have to multiply the coefficients in obs 1-3
**by the odds for married couples (the omitted category in the
**mlogit. The odds of homogamy for married couples come from
**the unadjusted log linear models (same as graphed above).

input rel_var beta_ml1990 beta_ml2000
1 1.175 1.163
2 1.161 1.143
3 1.121 1.094
4 1  1

end


gen h1990 = beta_ml1990*.7834288
gen h2000 = beta_ml2000*.7881284


#delimit ;


****black and white*** ;

graph bar (asis) h1990 h2000,  over(rel_var, relabel(1 `" "Same-Sex" "Male Couples" "' 2 `" "Same-Sex" "Female Couples" "'
                                             3 `" "Different-Sex" "Cohabiting Couples" "' 4 `" "Different-Sex" "Married Couples" "' )
         label(labsize(*1.0)) gap(120))
         nofill yscale(r(0.75 1.00) log) ylabel(0.75(.05)1.00, grid labsize(*1.0))  exclude0
         bar(1, bcolor(gs4) blcolor(black))  bar(2, bcolor(gs10) blcolor(black))
         scheme(s1color)
         graphregion(fcolor(gs16)) plotregion(style(none))
         ytitle("Odds")
         legend(order(1 2) label(1 "1990") label(2 "2000") size(*.95)) outergap(80) ;



    graph export graph_bystate_ny_20to49_2.wmf, replace fontface(garamond) ;


clear ;
set mem 100m ;


#delimit cr

input rel_var bdc2_90 bdc3_90 bdc4_90 bdc2_00 bdc3_00 bdc4_00
1  .796  1.183 1.383  .987   .946 1.315
2  .956  .900  1.167  1.188 1.083 1.071
3  1.265 1.058 1.078  1.282 1.068 1.009
4 1 1 1 1 1 1

end

gen dc2_90 = bdc2_90*0.3619808
gen dc3_90 = bdc3_90*0.4571998
gen dc4_90 = bdc4_90*0.3336757

gen dc2_00 = bdc2_00*.323386
gen dc3_00 = bdc3_00*.4352551
gen dc4_00 = bdc4_00*.3131675


gen dc24_00 = dc2_00*dc3_00*dc4_00
gen dc34_00 = dc3_00*dc4_00

gen dc24_90 = dc2_90*dc3_90*dc4_90
gen dc34_90 = dc3_90*dc4_90



#delimit ;

****black and white*** ;

graph bar (asis) dc24_90 dc24_00,  over(rel_var, relabel(1 `" "Same-Sex" "Male Couples" "' 2 `" "Same-Sex" "Female Couples" "'
                                             3 `" "Different-Sex" "Cohabiting Couples" "' 4 `" "Different-Sex" "Married Couples" "' )
         label(labsize(*1.0)) gap(120))
         nofill exclude0 yscale(r(.03 .3) log) ylabel(.05 .1 .2 .3, grid)
         bar(1, bcolor(gs4) blcolor(black))  bar(2, bcolor(gs10) blcolor(black))
         scheme(s1color)
         graphregion(fcolor(gs16)) plotregion(style(none))
         ytitle("Odds")
         legend(order(1 2) label(1 "1990") label(2 "2000") size(*.95)) outergap(80) ;



    graph export graph_bystate_ny_20to49_3.wmf, replace fontface(garamond) ;


****black and white*** ;

graph bar (asis) dc34_90 dc34_00,  over(rel_var, relabel(1 `" "Same-Sex" "Male Couples" "' 2 `" "Same-Sex" "Female Couples" "'
                                             3 `" "Different-Sex" "Cohabiting Couples" "' 4 `" "Different-Sex" "Married Couples" "' )
         label(labsize(*1.0)) gap(120))
         nofill exclude0 yscale(r(.03 .3) log) ylabel(.05 .1 .2 .3, grid)
         bar(1, bcolor(gs4) blcolor(black))  bar(2, bcolor(gs10) blcolor(black))
         scheme(s1color)
         graphregion(fcolor(gs16)) plotregion(style(none))
         ytitle("Odds")
         legend(order(1 2) label(1 "1990") label(2 "2000") size(*.95)) outergap(80) ;



    graph export graph_bystate_ny_20to49_4.wmf, replace fontface(garamond) ;


#delimit cr


****************
* OTHER STATES *
****************


clear

***ODDS OF RACE/ETHNIC ENDOGAMY FROM MLOGIT****


**These are the exponential multinomial logit coefficients
**(source:models_bystate_ny_20to49.log).
**To get the odds I have to multiply the coefficients in obs 1-3
**by the odds for married couples (the omitted category in the
**mlogit. The odds of homogamy for married couples come from
**the log linear models (source: baseline.log).

**These odds ratios can be found in the output "by year"

input rel_var beta_ml1990 beta_ml2000
1 .290 .248
2 .485 .407
3 .543 .543
4 1 1

end



*multiply the odds ratios by the baseline odds for married couples.
gen h1990 = beta_ml1990* 22.54563
gen h2000 = beta_ml2000* 20.25763


list

#delimit ;

cd "X:\Schwartz\Graf_Schwartz\DemResearchdraft\graphs" ;


****black and white*** ;

graph bar (asis) h1990 h2000,  over(rel_var, relabel(1 `" "Same-Sex" "Male Couples" "' 2 `" "Same-Sex" "Female Couples" "'
                                             3 `" "Different-Sex" "Cohabiting Couples" "' 4 `" "Different-Sex" "Married Couples" "' )
         label(labsize(*1.0)) gap(120))
         nofill exclude0 yscale(r(1 25) log) ylabel(5(5)25, grid)
         bar(1, bcolor(gs4) blcolor(black))  bar(2, bcolor(gs10) blcolor(black))
         scheme(s1color)
         graphregion(fcolor(gs16)) plotregion(style(none))
         ytitle("Odds")
         legend(order(1 2) label(1 "1990") label(2 "2000") size(*.95)) outergap(80) ;


    graph export graph_bystate_ny_20to49_5.wmf, replace fontface(garamond) ;



clear ;
set mem 100m ;


#delimit cr

***ABS(AGE DIFF) FROM MLOGIT****


**These are the exponential multinomial logit coefficients.
**To get the odds I have to multiply the coefficients in obs 1-3
**by the odds for married couples (the omitted category in the
**mlogit. The odds of homogamy for married couples come from
**the unadjusted log linear models (same as graphed above).

input rel_var beta_ml1990 beta_ml2000
1 1.211 1.163
2 1.172 1.151
3 1.133 1.100
4 1  1



end


gen h1990 = beta_ml1990*.7834288
gen h2000 = beta_ml2000*.7881284


#delimit ;


****black and white*** ;

graph bar (asis) h1990 h2000,  over(rel_var, relabel(1 `" "Same-Sex" "Male Couples" "' 2 `" "Same-Sex" "Female Couples" "'
                                             3 `" "Different-Sex" "Cohabiting Couples" "' 4 `" "Different-Sex" "Married Couples" "' )
         label(labsize(*1.0)) gap(120))
         nofill yscale(r(0.75 1.00) log) ylabel(0.75(.05)1.00, grid labsize(*1.0))  exclude0
         bar(1, bcolor(gs4) blcolor(black))  bar(2, bcolor(gs10) blcolor(black))
         scheme(s1color)
         graphregion(fcolor(gs16)) plotregion(style(none))
         ytitle("Odds")
         legend(order(1 2) label(1 "1990") label(2 "2000") size(*.95)) outergap(80) ;



    graph export graph_bystate_ny_20to49_6.wmf, replace fontface(garamond) ;


clear ;
set mem 100m ;


#delimit cr

input rel_var bdc2_90 bdc3_90 bdc4_90 bdc2_00 bdc3_00 bdc4_00
1  .875  1.193 1.298  .8922 1.025 1.292
2  1.135 1.068 1.134  1.515 .851  1.067
3  1.259 1.082 1.080  1.342 1.067 1.067
4 1 1 1 1 1 1



end

gen dc2_90 = bdc2_90*0.3619808
gen dc3_90 = bdc3_90*0.4571998
gen dc4_90 = bdc4_90*0.3336757

gen dc2_00 = bdc2_00*.323386
gen dc3_00 = bdc3_00*.4352551
gen dc4_00 = bdc4_00*.3131675


gen dc24_00 = dc2_00*dc3_00*dc4_00
gen dc34_00 = dc3_00*dc4_00

gen dc24_90 = dc2_90*dc3_90*dc4_90
gen dc34_90 = dc3_90*dc4_90



#delimit ;

****black and white*** ;

graph bar (asis) dc24_90 dc24_00,  over(rel_var, relabel(1 `" "Same-Sex" "Male Couples" "' 2 `" "Same-Sex" "Female Couples" "'
                                             3 `" "Different-Sex" "Cohabiting Couples" "' 4 `" "Different-Sex" "Married Couples" "' )
         label(labsize(*1.0)) gap(120))
         nofill exclude0 yscale(r(.03 .3) log) ylabel(.05 .1 .2 .3, grid)
         bar(1, bcolor(gs4) blcolor(black))  bar(2, bcolor(gs10) blcolor(black))
         scheme(s1color)
         graphregion(fcolor(gs16)) plotregion(style(none))
         ytitle("Odds")
         legend(order(1 2) label(1 "1990") label(2 "2000") size(*.95)) outergap(80) ;



    graph export graph_bystate_ny_20to49_7.wmf, replace fontface(garamond) ;


****black and white*** ;

graph bar (asis) dc34_90 dc34_00,  over(rel_var, relabel(1 `" "Same-Sex" "Male Couples" "' 2 `" "Same-Sex" "Female Couples" "'
                                             3 `" "Different-Sex" "Cohabiting Couples" "' 4 `" "Different-Sex" "Married Couples" "' )
         label(labsize(*1.0)) gap(120))
         nofill exclude0 yscale(r(.03 .3) log) ylabel(.05 .1 .2 .3, grid)
         bar(1, bcolor(gs4) blcolor(black))  bar(2, bcolor(gs10) blcolor(black))
         scheme(s1color)
         graphregion(fcolor(gs16)) plotregion(style(none))
         ytitle("Odds")
         legend(order(1 2) label(1 "1990") label(2 "2000") size(*.95)) outergap(80) ;



    graph export graph_bystate_ny_20to49_8.wmf, replace fontface(garamond) ;




