
**************************************************************************
* SAMPLE: Use only couples in which both partners are between the ages of*
* 20-34                                                                  *
**************************************************************************

************************************************************************
* This file uses the alternate version of race/ethnicity in which      *
* biracial whites are coded as white                                   *
************************************************************************


clear
macro drop _all
program drop _all
set more off
set linesize 80
version 9.0

capture log close
log using "/project/graf_schwartz/demresearch/models_svy_sep.log",replace

set mem 900m




use if (age0 >= 20 & age0 <= 34) & (age1 >= 20 & age1 <= 34)  using "/project/graf_schwartz/demresearch/couple_2000.dta"
gen y = 2000

append using "/project/graf_schwartz/demresearch/couple_1990.dta"
replace y = 1990 if y == .



svyset [pweight=hhwt]
svydes


**********
* SELECT *
**********

keep if (age0 >= 20 & age0 <= 34) & (age1 >= 20 & age1 <= 34)

bysort y: tab rel_var
bysort y: tab rel_var [fw=hhwt]

*Note that the survey command is equal to the frequency weights.
*The frequency weights take much less time to run so I use frequency weights
*for the crosstabs

svy: tab rel_var if y == 2000



*drop couples in which either partners' marital status was imputed

gen marimp = (qmarst0 ~= 0 | qmarst1 ~= 0)


bysort y rel_var: tab marimp


drop if marimp == 1


bysort y: tab rel_var
bysort y: tab rel_var [fw=hhwt]



***FOR NOW, use the person weight of the householder.  This means the sample
***         is representative of relationships among 20-34 year old household
***         heads.



***USE ALTERNATIVE RACE VARIABLE***

   replace re1 = re21 if y == 2000
   replace re0 = re20 if y == 2000

   drop re2*


***HOMOGAMY VARIABLES AND DESCRIPTIVES ***


  **(For point estimates of correlation coefficients with survey
  ** data use aweights. See  http://www.stata.com/support/faqs/stat/survey.html)

   foreach i in age educ_l re {

    gen o_`i' = (`i'0 == `i'1)

    bysort rel_var: corr `i'0 `i'1  [aw=hhwt]
    tab rel_var o_`i' [fw=hhwt],nofreq row

   }


  **Odds ratios**

  quietly tab re0, gen(re0)
  quietly tab re1, gen(re1)

  gen freq = 1

  **OVERALL**

    forval i = 1/4 {
     preserve
      keep if rel_var == `i'
      collapse (sum) freq hhwt, by(re0 re1)
       quietly gen o_re = (re0 == re1)
       display "***********************************"
       display "***RE = OVERALL, REL_VAR == `i' ***"
       display "***********************************"
       xi: glm hhwt i.re0 i.re1 o_re, family(poisson) link(log) eform
     restore
    }

  **BY RACE/ETHNICITY**

    forval i = 1/4 {
     forval j = 1/4 {
      preserve
       keep if rel_var == `j'
       collapse (sum) freq hhwt, by(re0`i' re1`i')
        quietly gen o_re = (re0`i' == re1`i')
        display "*******************************"
        display "***RE = `i', REL_VAR == `j' ***"
        display "*******************************"
        xi: glm hhwt i.re0`i' i.re1`i' o_re, family(poisson) link(log) eform
      restore
     }
    }




***RACE/ETHNICITY DIAGONAL***

   forvalues i = 1/4 {
    gen o_re_`i' = (re0 == re1 & re0 == `i')
   }



***SYMMETRY RACE/ETHNICITY***

   gen     sym_re = 1 if (re1 == 1 & re0 == 1)
   replace sym_re = 2 if (re1 == 2 & re0 == 1) | (re1 == 1 & re0 == 2)
   replace sym_re = 3 if (re1 == 3 & re0 == 1) | (re1 == 1 & re0 == 3)
   replace sym_re = 4 if (re1 == 4 & re0 == 1) | (re1 == 1 & re0 == 4)
   replace sym_re = 5 if (re1 == 2 & re0 == 2)
   replace sym_re = 6 if (re1 == 3 & re0 == 2) | (re1 == 2 & re0 == 3)
   replace sym_re = 7 if (re1 == 4 & re0 == 2) | (re1 == 2 & re0 == 4)
   replace sym_re = 8 if (re1 == 3 & re0 == 3)
   replace sym_re = 9 if (re1 == 3 & re0 == 4) | (re1 == 4 & re0 == 3)
   replace sym_re =10 if (re1 == 4 & re0 == 4)



***AGE DIFFERENCES AND DESCRIPTIVES***

   gen age_d = abs(age0-age1)
   table rel_var [fw=hhwt], c(med age_d mean age_d sd age_d)

   gen age_5d = (age_d >= 5 & age_d ~= . )
   tab rel_var age_5d [fw=hhwt], nofreq row



     ***Generate linear age term for UA

       foreach num of numlist 0 1 {
        gen     agecl`num' = 22 if agec`num' == 1
        replace agecl`num' = 27 if agec`num' == 2
        replace agecl`num' = 32 if agec`num' == 3
       }

      gen uaagec = agecl1*agecl0
      gen abs_aged = abs(agecl1-agecl0)


***DETAILED RACE/ETH DESCRIPTIVES**

   bysort rel_var: tab re1 re0 [fw=hhwt], row col cell nofreq


***CROSSINGS VARIABLES***

   gen dc2 = (educ1 < 2 & educ0 >= 2) | (educ1 >= 2 & educ0 < 2)
   gen dc3 = (educ1 < 3 & educ0 >= 3) | (educ1 >= 3 & educ0 < 3)
   gen dc4 = (educ1 < 4 & educ0 >= 4) | (educ1 >= 4 & educ0 < 4)


***UNIFORM ASSOCIATION, EDUCATION***

   gen uaeduc = educ_l1*educ_l0
   gen abs_edd = abs(educ_l1-educ_l0)


**EDUCATIONAL HOMOGAMY**


  quietly tab educ0, gen(educ0)
  quietly tab educ1, gen(educ1)

  **OVERALL**

    forval i = 1/4 {
     preserve
      keep if rel_var == `i'
      collapse (sum) freq hhwt, by(educ0 educ1)
       quietly gen o_ed = (educ0 == educ1)
       display "***********************************"
       display "***RE = OVERALL, REL_VAR == `i' ***"
       display "***********************************"
       xi: glm hhwt i.educ0 i.educ1 o_ed, family(poisson) link(log) eform
     restore
    }

  **BY EDUCATION**

    forval i = 1/4 {
     forval j = 1/4 {
      preserve
       keep if rel_var == `j'
       collapse (sum) freq hhwt, by(educ0`i' educ1`i')
        quietly gen o_ed = (educ0`i' == educ1`i')
        display "*******************************"
        display "***ED = `i', REL_VAR == `j' ***"
        display "*******************************"
        xi: glm hhwt i.educ0`i' i.educ1`i' o_ed, family(poisson) link(log) eform
      restore
     }
    }



***Either partner in couple geographically mobile***

   gen gmc = (geog_mob1 == 1 | geog_mob0 == 1)
   tab rel_var gmc [fw=hhwt], nofreq row



***Bi-variate relationship between homogamy and geographic mobility

   tab o_educ gmc , chi2 col nofreq
   tab o_re gmc , chi2 col nofreq
   ttest age_d, by(gmc)





******************************
* DEAL WITH THE WEIGHTS HERE *
******************************

     #delimit ;

     ***This part deflates the weights so that the original
        sample size is maintained ;


        bysort rel_var: egen double sumwgt = sum(hhwt) ;
        bysort rel_var: gen N = _N  ;


        bysort rel_var: gen double deflate = N/sumwgt ;



        *preserve original weight variables ;
         gen oweight = hhwt ;

        bysort rel_var: gen double WEIGHT = oweight*deflate ;




#delimit cr




***************************
* Run a multinomial logit *
***************************


local base = "i.agec1*i.y i.agec0*i.y i.educ1*i.y i.educ0*i.y i.re1*i.y i.re0*i.y"



**********************
* UNWEIGHTED RESULTS *
**********************




**Baseline model

  xi: mlogit rel_var `base', rrr base(1)


**Test for differences in age associations

  xi: mlogit rel_var `base' uaagec , rrr base(1)
  xi: mlogit rel_var `base' abs_aged , rrr base(1)

**Have differences changed over time?

  xi: mlogit rel_var `base' i.y*abs_aged , rrr base(1)



**Test for differences in sorting by race/ethnicity

  xi: mlogit rel_var `base' o_re , rrr base(1)
  xi: mlogit rel_var `base' o_re_* , rrr base(1)
  xi: mlogit rel_var `base' i.sym_re , rrr base(1)

**Have differences changed over time?

  xi: mlogit rel_var `base' i.y*o_re , rrr base(1)




**Test for differences in sorting by education

  xi: mlogit rel_var `base' o_educ , rrr base(1)
  xi: mlogit rel_var `base' uaeduc , rrr base(1)
  xi: mlogit rel_var `base' abs_edd , rrr base(1)
  xi: mlogit rel_var `base' dc2 dc3 dc4 , rrr base(1)
      est store dc


**Have differences changed over time?

  xi: mlogit rel_var `base' i.y*dc2 i.y*dc3 i.y*dc4 , rrr base(1)
  lrtest dc



**********************
* WEIGHTED RESULTS *
**********************



**Baseline model

  xi: mlogit rel_var `base'[pw=hhwt] , rrr base(1)



**Test for differences in age associations

  xi: mlogit rel_var `base' uaagec [pw=hhwt] , rrr base(1)
  xi: mlogit rel_var `base' abs_aged [pw=hhwt] , rrr base(1)




**Have differences changed over time?

  xi: mlogit rel_var `base' i.y*abs_aged [pw=hhwt] , rrr base(1)
  xi: mlogit rel_var `base' i.y*abs_aged [pw=hhwt] , rrr base(2)
  xi: mlogit rel_var `base' i.y*abs_aged [pw=hhwt] , rrr base(3)



**Test for differences in sorting by race/ethnicity

  xi: mlogit rel_var `base' o_re [pw=hhwt] , rrr base(1)
  xi: mlogit rel_var `base' o_re_* [pw=hhwt] , rrr base(1)
  xi: mlogit rel_var `base' i.sym_re [pw=hhwt] , rrr base(1)

**Have differences changed over time?

  xi: mlogit rel_var `base' i.y*o_re [pw=hhwt] , rrr base(1)
  xi: mlogit rel_var `base' i.y*o_re [pw=hhwt] , rrr base(2)
  xi: mlogit rel_var `base' i.y*o_re [pw=hhwt] , rrr base(3)




**Test for differences in sorting by education

  xi: mlogit rel_var `base' o_educ [pw=hhwt] , rrr base(1)
  xi: mlogit rel_var `base' uaeduc [pw=hhwt] , rrr base(1)
  xi: mlogit rel_var `base' abs_edd [pw=hhwt] , rrr base(1)
  xi: mlogit rel_var `base' dc2 dc3 dc4 [pw=hhwt] , rrr base(1)
      est store dc



**Have differences changed over time?

  xi: mlogit rel_var `base' i.y*dc2 i.y*dc3 i.y*dc4 [pw=hhwt] , rrr base(1)
  lincom [2]_IyXdc3_2000 + [2]_IyXdc4_2000
  lincom [3]_IyXdc3_2000 + [3]_IyXdc4_2000
  lincom [4]_IyXdc3_2000 + [4]_IyXdc4_2000

  lincom [2]_IyXdc2_2000 + [2]_IyXdc3_2000 + [2]_IyXdc4_2000
  lincom [3]_IyXdc2_2000 + [3]_IyXdc3_2000 + [3]_IyXdc4_2000
  lincom [4]_IyXdc2_2000 + [4]_IyXdc3_2000 + [4]_IyXdc4_2000

  fitstat


  xi: mlogit rel_var `base' i.y*dc2 i.y*dc3 i.y*dc4 [pw=hhwt], rrr base(2)
  lincom [1]_IyXdc3_2000 + [1]_IyXdc4_2000
  lincom [3]_IyXdc3_2000 + [3]_IyXdc4_2000
  lincom [4]_IyXdc3_2000 + [4]_IyXdc4_2000

  lincom [1]_IyXdc2_2000 + [1]_IyXdc3_2000 + [1]_IyXdc4_2000
  lincom [3]_IyXdc2_2000 + [3]_IyXdc3_2000 + [3]_IyXdc4_2000
  lincom [4]_IyXdc2_2000 + [4]_IyXdc3_2000 + [4]_IyXdc4_2000

  xi: mlogit rel_var `base' i.y*dc2 i.y*dc3 i.y*dc4 [pw=hhwt], rrr base(3)
  lincom [1]_IyXdc3_2000 + [1]_IyXdc4_2000
  lincom [2]_IyXdc3_2000 + [2]_IyXdc4_2000
  lincom [4]_IyXdc3_2000 + [4]_IyXdc4_2000

  lincom [1]_IyXdc2_2000 + [1]_IyXdc3_2000 + [1]_IyXdc4_2000
  lincom [2]_IyXdc2_2000 + [2]_IyXdc3_2000 + [2]_IyXdc4_2000
  lincom [4]_IyXdc2_2000 + [4]_IyXdc3_2000 + [4]_IyXdc4_2000

  fitstat


**Separately by year

  xi: mlogit rel_var `base' i.y*dc2 i.y*dc3 i.y*dc4 [pw=hhwt] if y == 1990, rrr base(1)
  lincom [2]dc3 + [2]dc4
  lincom [3]dc3 + [3]dc4
  lincom [4]dc3 + [4]dc4

  lincom [2]dc2 + [2]dc3 + [2]dc4
  lincom [3]dc2 + [3]dc3 + [3]dc4
  lincom [4]dc2 + [4]dc3 + [4]dc4



  xi: mlogit rel_var `base' i.y*dc2 i.y*dc3 i.y*dc4 [pw=hhwt] if y == 2000, rrr base(1)
  lincom [2]dc3 + [2]dc4
  lincom [3]dc3 + [3]dc4
  lincom [4]dc3 + [4]dc4

  lincom [2]dc2 + [2]dc3 + [2]dc4
  lincom [3]dc2 + [3]dc3 + [3]dc4
  lincom [4]dc2 + [4]dc3 + [4]dc4

  xi: mlogit rel_var `base'  i.y*dc2 i.y*dc3 i.y*dc4 [pw=hhwt] if y == 1990, rrr base(2)
  lincom [1]dc3 + [1]dc4
  lincom [3]dc3 + [3]dc4
  lincom [4]dc3 + [4]dc4

  lincom [1]dc2 + [1]dc3 + [1]dc4
  lincom [3]dc2 + [3]dc3 + [3]dc4
  lincom [4]dc2 + [4]dc3 + [4]dc4

  xi: mlogit rel_var `base'  i.y*dc2 i.y*dc3 i.y*dc4 [pw=hhwt] if y == 2000, rrr base(2)
  lincom [1]dc3 + [1]dc4
  lincom [3]dc3 + [3]dc4
  lincom [4]dc3 + [4]dc4

  lincom [1]dc2 + [1]dc3 + [1]dc4
  lincom [3]dc2 + [3]dc3 + [3]dc4
  lincom [4]dc2 + [4]dc3 + [4]dc4

  xi: mlogit rel_var `base'  i.y*dc2 i.y*dc3 i.y*dc4 [pw=hhwt] if y == 1990, rrr base(3)
  lincom [1]dc3 + [1]dc4
  lincom [2]dc3 + [2]dc4
  lincom [4]dc3 + [4]dc4

  lincom [1]dc2 + [1]dc3 + [1]dc4
  lincom [2]dc2 + [2]dc3 + [2]dc4
  lincom [4]dc2 + [4]dc3 + [4]dc4

  xi: mlogit rel_var `base'  i.y*dc2 i.y*dc3 i.y*dc4 [pw=hhwt] if y == 2000, rrr base(3)
  lincom [1]dc3 + [1]dc4
  lincom [2]dc3 + [2]dc4
  lincom [4]dc3 + [4]dc4

  lincom [1]dc2 + [1]dc3 + [1]dc4
  lincom [2]dc2 + [2]dc3 + [2]dc4
  lincom [4]dc2 + [4]dc3 + [4]dc4




