

clear
macro drop _all
program drop _all
set more off
set linesize 80
set mem 1500m

capture log close
log using "sensitivity_90.log",replace

**********************************************************
* Extract: ngraf008   Extract Date: 3/1/07 *
**********************************************************




/* Important: you need to put the .dat and .do files in one folder/
   directory and then set the working folder to that folder. */


#delimit ;
infix ///
 byte    year          1-2 ///
 byte    datanum       3-4 ///
 double  serial        5-12 ///
 byte    numprec      13-14 ///
 byte    subsamp      15-16 ///
 int     hhwt         17-20 ///
 byte    statefip     21-22 ///
 byte    urban        23 ///
 int     metarea      24-26 ///
 int     city         27-29 ///
 long    citypop      30-34 ///
 byte    sizepl       35-36 ///
 long    puma         37-41 ///
 byte    pumatype     42-43 ///
 byte    gq           44 ///
 byte    pernum       45-46 ///
 int     perwt        47-50 ///
 byte    momloc       51-52 ///
 byte    stepmom      53 ///
 byte    momrule      54 ///
 byte    poploc       55-56 ///
 byte    steppop      57 ///
 byte    poprule      58 ///
 byte    sploc        59-60 ///
 byte    nchild       61 ///
 int     related      62-65 ///
 int     age          66-68 ///
 byte    sex          69 ///
 byte    marst        70 ///
 int     race         71 ///
 int     raced        71-73 ///
 long    bpl          74-76 ///
 int     hispan       77 ///
 byte    educrec      78 ///
 byte    empstatd     79-80 ///
 byte    migrate5     81 ///
 int     migplac5     82-84 ///
 byte    qage         85 ///
 byte    qmarst       86 ///
 byte    qrelate      87 ///
 byte    qsex         88 ///
 byte    qbpl         89 ///
 byte    qhispan      90 ///
 byte    qrace        91 ///
 byte    qeduc        92 ///
/*crs 11/16/06: I am re-running the file without restrictions for employment status*/
/*crs 2/16/07: Re-run this excluding those in group quarters and in vacant housing
               units.  Also exclude those with age imputed.  Following Gates et al 2000.*/
/*crs 3/3/07: Re-run the file including detailed race categories*/


 using "ngraf008.dat"
    if (age >= 18 & age <= 65)  &
       (qsex == 0 & qrelate == 0) &
       (gq == 1 | gq == 2 | gq == 5) &
       (qage == 0) ;

#delimit cr

label var year "Census year"
label var datanum "Data set number"
label var serial "Household serial number"
label var numprec "Number of person records following"
label var subsamp "Subsample number"
label var hhwt "Household weight"
label var statefip "State (FIPS code)"
label var urban "Urban/rural status"
label var metarea "Metropolitan area [general version]"
label var city "City [general version]"
label var citypop "City population"
label var sizepl "Size of place"
label var puma "Public Use Microdata Area"
label var pumatype "PUMA type"
label var gq "Group quarters status"
label var pernum "Person number in sample unit"
label var perwt "Person weight"
label var momloc "Mother's location in the household"
label var stepmom "Probable step/adopted mother"
label var momrule "Rule for linking mother"
label var poploc "Father's location in the household"
label var steppop "Probable step/adopted father"
label var poprule "Rule for linking father"
label var sploc "Spouse's location in household"
label var nchild "Number of own children in the household"
label var related "Relationship to household head [detailed version]"
label var age "Age"
label var sex "Sex"
label var marst "Marital status"
label var race "Race [general version]"
label var raced "Race [detailed version]"
label var bpl "Birthplace [general version]"
label var hispan "Hispanic origin [general version]"
label var educrec "Educational attainment recode"
label var empstatd "Employment status [detailed version]"
label var migrate5 "Migration status, 5 years [general version]"
label var migplac5 "State or country of residence 5 years ago"
label var qage "Flag for Age"
label var qmarst "Flag for Marst"
label var qrelate "Flag for Relate"
label var qsex "Flag for Sex"
label var qbpl "Flag for Bpl, Nativity"
label var qhispan "Flag for Hispan"
label var qrace "Flag for Race, Racamind, Racasian, Racblk, Racpais, Racwht, Racoth, Racnum, Rachist, Probai, Probblk, Proboth, Probwht, Probapi"
label var qeduc "Flag for Educrec, Higrade, Educ99"

label define yearlbl 00 "2000"
label define yearlbl 01 "2001", add
label define yearlbl 02 "2002", add
label define yearlbl 03 "2003", add
label define yearlbl 04 "2004", add
label define yearlbl 05 "2005", add
label define yearlbl 85 "1850", add
label define yearlbl 86 "1860", add
label define yearlbl 87 "1870", add
label define yearlbl 88 "1880", add
label define yearlbl 90 "1900", add
label define yearlbl 91 "1910", add
label define yearlbl 92 "1920", add
label define yearlbl 93 "1930", add
label define yearlbl 94 "1940", add
label define yearlbl 95 "1950", add
label define yearlbl 96 "1960", add
label define yearlbl 97 "1970", add
label define yearlbl 98 "1980", add
label define yearlbl 99 "1990", add
label values year yearlbl

label values datanum datanumlbl

label values serial seriallbl

label define numpreclbl 00 "Vacant household"
label define numpreclbl 01 "1 person record", add
label define numpreclbl 02 "2", add
label define numpreclbl 03 "3", add
label define numpreclbl 04 "4", add
label define numpreclbl 05 "5", add
label define numpreclbl 06 "6", add
label define numpreclbl 07 "7", add
label define numpreclbl 08 "8", add
label define numpreclbl 09 "9", add
label define numpreclbl 10 "10", add
label define numpreclbl 11 "11", add
label define numpreclbl 12 "12", add
label define numpreclbl 13 "13", add
label define numpreclbl 14 "14", add
label define numpreclbl 15 "15", add
label define numpreclbl 16 "16", add
label define numpreclbl 17 "17", add
label define numpreclbl 18 "18", add
label define numpreclbl 19 "19", add
label define numpreclbl 20 "20", add
label define numpreclbl 21 "21", add
label define numpreclbl 22 "22", add
label define numpreclbl 23 "23", add
label define numpreclbl 24 "24", add
label define numpreclbl 25 "25", add
label define numpreclbl 26 "26", add
label define numpreclbl 27 "27", add
label define numpreclbl 28 "28", add
label define numpreclbl 29 "29", add
label define numpreclbl 30 "30", add
label values numprec numpreclbl

label define subsamplbl 00 "First 1% subsample"
label define subsamplbl 01 "2nd 1% subsample", add
label define subsamplbl 02 "02", add
label define subsamplbl 03 "03", add
label define subsamplbl 04 "04", add
label define subsamplbl 05 "05", add
label define subsamplbl 06 "06", add
label define subsamplbl 07 "07", add
label define subsamplbl 08 "08", add
label define subsamplbl 09 "09", add
label define subsamplbl 10 "10", add
label define subsamplbl 11 "11", add
label define subsamplbl 12 "12", add
label define subsamplbl 13 "13", add
label define subsamplbl 14 "14", add
label define subsamplbl 15 "15", add
label define subsamplbl 16 "16", add
label define subsamplbl 17 "17", add
label define subsamplbl 18 "18", add
label define subsamplbl 19 "19", add
label define subsamplbl 20 "20", add
label define subsamplbl 21 "21", add
label define subsamplbl 22 "22", add
label define subsamplbl 23 "23", add
label define subsamplbl 24 "24", add
label define subsamplbl 25 "25", add
label define subsamplbl 26 "26", add
label define subsamplbl 27 "27", add
label define subsamplbl 28 "28", add
label define subsamplbl 29 "29", add
label define subsamplbl 30 "30", add
label define subsamplbl 31 "31", add
label define subsamplbl 32 "32", add
label define subsamplbl 33 "33", add
label define subsamplbl 34 "34", add
label define subsamplbl 35 "35", add
label define subsamplbl 36 "36", add
label define subsamplbl 37 "37", add
label define subsamplbl 38 "38", add
label define subsamplbl 39 "39", add
label define subsamplbl 40 "40", add
label define subsamplbl 41 "41", add
label define subsamplbl 42 "42", add
label define subsamplbl 43 "43", add
label define subsamplbl 44 "44", add
label define subsamplbl 45 "45", add
label define subsamplbl 46 "46", add
label define subsamplbl 47 "47", add
label define subsamplbl 48 "48", add
label define subsamplbl 49 "49", add
label define subsamplbl 50 "50", add
label define subsamplbl 51 "51", add
label define subsamplbl 52 "52", add
label define subsamplbl 53 "53", add
label define subsamplbl 54 "54", add
label define subsamplbl 55 "55", add
label define subsamplbl 56 "56", add
label define subsamplbl 57 "57", add
label define subsamplbl 58 "58", add
label define subsamplbl 59 "59", add
label define subsamplbl 60 "60", add
label define subsamplbl 61 "61", add
label define subsamplbl 62 "62", add
label define subsamplbl 63 "63", add
label define subsamplbl 64 "64", add
label define subsamplbl 65 "65", add
label define subsamplbl 66 "66", add
label define subsamplbl 67 "67", add
label define subsamplbl 68 "68", add
label define subsamplbl 69 "69", add
label define subsamplbl 70 "70", add
label define subsamplbl 71 "71", add
label define subsamplbl 72 "72", add
label define subsamplbl 73 "73", add
label define subsamplbl 74 "74", add
label define subsamplbl 75 "75", add
label define subsamplbl 76 "76", add
label define subsamplbl 77 "77", add
label define subsamplbl 78 "78", add
label define subsamplbl 79 "79", add
label define subsamplbl 80 "80", add
label define subsamplbl 81 "81", add
label define subsamplbl 82 "82", add
label define subsamplbl 83 "83", add
label define subsamplbl 84 "84", add
label define subsamplbl 85 "85", add
label define subsamplbl 86 "86", add
label define subsamplbl 87 "87", add
label define subsamplbl 88 "88", add
label define subsamplbl 89 "89", add
label define subsamplbl 90 "90", add
label define subsamplbl 91 "91", add
label define subsamplbl 92 "92", add
label define subsamplbl 93 "93", add
label define subsamplbl 94 "94", add
label define subsamplbl 95 "95", add
label define subsamplbl 96 "96", add
label define subsamplbl 97 "97", add
label define subsamplbl 98 "98", add
label define subsamplbl 99 "99", add
label values subsamp subsamplbl

label values hhwt hhwtlbl

label define statefiplbl 01 "Alabama", add
label define statefiplbl 02 "Alaska", add
label define statefiplbl 04 "Arizona", add
label define statefiplbl 05 "Arkansas", add
label define statefiplbl 06 "California", add
label define statefiplbl 08 "Colorado", add
label define statefiplbl 09 "Connecticut", add
label define statefiplbl 10 "Delaware", add
label define statefiplbl 11 "District of Columbia", add
label define statefiplbl 12 "Florida", add
label define statefiplbl 13 "Georgia", add
label define statefiplbl 15 "Hawaii", add
label define statefiplbl 16 "Idaho", add
label define statefiplbl 17 "Illinois", add
label define statefiplbl 18 "Indiana", add
label define statefiplbl 19 "Iowa", add
label define statefiplbl 20 "Kansas", add
label define statefiplbl 21 "Kentucky", add
label define statefiplbl 22 "Louisiana", add
label define statefiplbl 23 "Maine", add
label define statefiplbl 24 "Maryland", add
label define statefiplbl 25 "Massachusetts", add
label define statefiplbl 26 "Michigan", add
label define statefiplbl 27 "Minnesota", add
label define statefiplbl 28 "Mississippi", add
label define statefiplbl 29 "Missouri", add
label define statefiplbl 30 "Montana", add
label define statefiplbl 31 "Nebraska", add
label define statefiplbl 32 "Nevada", add
label define statefiplbl 33 "New Hampshire", add
label define statefiplbl 34 "New Jersey", add
label define statefiplbl 35 "New Mexico", add
label define statefiplbl 36 "New York", add
label define statefiplbl 37 "North Carolina", add
label define statefiplbl 38 "North Dakota", add
label define statefiplbl 39 "Ohio", add
label define statefiplbl 40 "Oklahoma", add
label define statefiplbl 41 "Oregon", add
label define statefiplbl 42 "Pennsylvania", add
label define statefiplbl 44 "Rhode island", add
label define statefiplbl 45 "South Carolina", add
label define statefiplbl 46 "South Dakota", add
label define statefiplbl 47 "Tennessee", add
label define statefiplbl 48 "Texas", add
label define statefiplbl 49 "Utah", add
label define statefiplbl 50 "Vermont", add
label define statefiplbl 51 "Virginia", add
label define statefiplbl 53 "Washington", add
label define statefiplbl 54 "West Virginia", add
label define statefiplbl 55 "Wisconsin", add
label define statefiplbl 56 "Wyoming", add
label define statefiplbl 61 "Maine-New Hampshire-Vermont", add
label define statefiplbl 62 "Massachusetts-Rhode Island", add
label define statefiplbl 63 "Minnesota-Iowa-Missouri-Kansas-Nebraska-S.Dakota-N.Dakota", add
label define statefiplbl 64 "Maryland-Delaware", add
label define statefiplbl 65 "Montana-Idaho-Wyoming", add
label define statefiplbl 66 "Utah-Nevada", add
label define statefiplbl 67 "Arizona-New Mexico", add
label define statefiplbl 68 "Alaska-Hawaii", add
label define statefiplbl 72 "Puerto Rico", add
label define statefiplbl 97 "Military/Mil. Reservation", add
label define statefiplbl 99 "State not identified", add
label values statefip statefiplbl

label define urbanlbl 0 "N/A"
label define urbanlbl 1 "Rural", add
label define urbanlbl 2 "Urban", add
label values urban urbanlbl

label define metarealbl 000 "Not identifiable or not in an MSA"
label define metarealbl 004 "Abilene, TX", add
label define metarealbl 008 "Akron, OH", add
label define metarealbl 012 "Albany, GA", add
label define metarealbl 016 "Albany-Schenectady-Troy, NY", add
label define metarealbl 020 "Albuquerque, NM", add
label define metarealbl 022 "Alexandria, LA", add
label define metarealbl 024 "Allentown-Bethlehem-Easton, PA/NJ", add
label define metarealbl 028 "Altoona, PA", add
label define metarealbl 032 "Amarillo, TX", add
label define metarealbl 038 "Anchorage, AK", add
label define metarealbl 040 "Anderson, IN", add
label define metarealbl 044 "Ann Arbor, MI", add
label define metarealbl 045 "Anniston, AL", add
label define metarealbl 046 "Appleton-Oskosh-Neenah, WI", add
label define metarealbl 048 "Asheville, NC", add
label define metarealbl 050 "Athens, GA", add
label define metarealbl 052 "Atlanta, GA", add
label define metarealbl 056 "Atlantic City, NJ", add
label define metarealbl 058 "Auburn-Opekika, AL", add
label define metarealbl 060 "Augusta-Aiken, GA-SC", add
label define metarealbl 064 "Austin, TX", add
label define metarealbl 068 "Bakersfield, CA", add
label define metarealbl 072 "Baltimore, MD", add
label define metarealbl 073 "Bangor, ME", add
label define metarealbl 074 "Barnstable-Yarmouth, MA", add
label define metarealbl 076 "Baton Rouge, LA", add
label define metarealbl 078 "Battle Creek, MI", add
label define metarealbl 084 "Beaumont-Port Arthur-Orange,TX", add
label define metarealbl 086 "Bellingham, WA", add
label define metarealbl 087 "Benton Harbor, MI", add
label define metarealbl 088 "Billings, MT", add
label define metarealbl 092 "Biloxi-Gulfport, MS", add
label define metarealbl 096 "Binghamton, NY", add
label define metarealbl 100 "Birmingham, AL", add
label define metarealbl 102 "Bloomington, IN", add
label define metarealbl 104 "Bloomington-Normal, IL", add
label define metarealbl 108 "Boise City, ID", add
label define metarealbl 112 "Boston, MA-NH", add
label define metarealbl 114 "Bradenton, FL", add
label define metarealbl 115 "Bremerton, WA", add
label define metarealbl 116 "Bridgeport, CT", add
label define metarealbl 120 "Brockton, MA", add
label define metarealbl 124 "Brownsville-Harlingen-San Benito, TX", add
label define metarealbl 126 "Bryan-College Station, TX", add
label define metarealbl 128 "Buffalo-Niagara Falls, NY", add
label define metarealbl 130 "Burlington, NC", add
label define metarealbl 131 "Burlington, VT", add
label define metarealbl 132 "Canton, OH", add
label define metarealbl 135 "Casper, WY", add
label define metarealbl 136 "Cedar Rapids, IA", add
label define metarealbl 140 "Champaign-Urbana-Rantoul, IL", add
label define metarealbl 144 "Charleston-N.Charleston,SC", add
label define metarealbl 148 "Charleston, WV", add
label define metarealbl 152 "Charlotte-Gastonia-Rock Hill, NC-SC", add
label define metarealbl 154 "Charlottesville, VA", add
label define metarealbl 156 "Chattanooga, TN/GA", add
label define metarealbl 158 "Cheyenne, WY", add
label define metarealbl 160 "Chicago, IL", add
label define metarealbl 162 "Chico, CA", add
label define metarealbl 164 "Cincinnati-Hamilton, OH/KY/IN", add
label define metarealbl 166 "Clarksville- Hopkinsville, TN/KY", add
label define metarealbl 168 "Cleveland, OH", add
label define metarealbl 172 "Colorado Springs, CO", add
label define metarealbl 174 "Columbia, MO", add
label define metarealbl 176 "Columbia, SC", add
label define metarealbl 180 "Columbus, GA/AL", add
label define metarealbl 184 "Columbus, OH", add
label define metarealbl 188 "Corpus Christi, TX", add
label define metarealbl 190 "Cumberland, MD/WV", add
label define metarealbl 192 "Dallas-Fort Worth, TX", add
label define metarealbl 193 "Danbury, CT", add
label define metarealbl 195 "Danville, VA", add
label define metarealbl 196 "Davenport, IA-Rock Island -Moline, IL", add
label define metarealbl 200 "Dayton-Springfield, OH", add
label define metarealbl 202 "Daytona Beach, FL", add
label define metarealbl 203 "Decatur, AL", add
label define metarealbl 204 "Decatur, IL", add
label define metarealbl 208 "Denver-Boulder, CO", add
label define metarealbl 212 "Des Moines, IA", add
label define metarealbl 216 "Detroit, MI", add
label define metarealbl 218 "Dothan, AL", add
label define metarealbl 219 "Dover, DE", add
label define metarealbl 220 "Dubuque, IA", add
label define metarealbl 224 "Duluth-Superior, MN/WI", add
label define metarealbl 228 "Dutchess Co., NY", add
label define metarealbl 229 "Eau Claire, WI", add
label define metarealbl 231 "El Paso, TX", add
label define metarealbl 232 "Elkhart-Goshen, IN", add
label define metarealbl 233 "Elmira, NY", add
label define metarealbl 234 "Enid, OK", add
label define metarealbl 236 "Erie, PA", add
label define metarealbl 240 "Eugene-Springfield, OR", add
label define metarealbl 244 "Evansville, IN/KY", add
label define metarealbl 252 "Fargo-Morehead, ND/MN", add
label define metarealbl 256 "Fayetteville, NC", add
label define metarealbl 258 "Fayetteville-Springdale, AR", add
label define metarealbl 260 "Fitchburg-Leominster, MA", add
label define metarealbl 262 "Flagstaff, AZ-UT", add
label define metarealbl 264 "Flint, MI", add
label define metarealbl 265 "Florence, AL", add
label define metarealbl 266 "Florence, SC", add
label define metarealbl 267 "Fort Collins-Loveland, CO", add
label define metarealbl 268 "Fort Lauderdale-Hollywood-Pompano Beach, FL", add
label define metarealbl 270 "Fort Myers-Cape Coral, FL", add
label define metarealbl 271 "Fort Pierce, FL", add
label define metarealbl 272 "Fort Smith, AR/OK", add
label define metarealbl 275 "Fort Walton Beach, FL", add
label define metarealbl 276 "Fort Wayne, IN", add
label define metarealbl 284 "Fresno, CA", add
label define metarealbl 288 "Gadsden, AL", add
label define metarealbl 290 "Gainesville, FL", add
label define metarealbl 292 "Galveston-Texas City, TX", add
label define metarealbl 297 "Glens Falls, NY", add
label define metarealbl 298 "Goldsboro, NC", add
label define metarealbl 299 "Grand Forks, ND", add
label define metarealbl 300 "Grand Rapids, MI", add
label define metarealbl 301 "Grand Junction, CO", add
label define metarealbl 304 "Great Falls, MT", add
label define metarealbl 306 "Greeley, CO", add
label define metarealbl 308 "Green Bay, WI", add
label define metarealbl 312 "Greensboro-Winston Salem-High Point, NC", add
label define metarealbl 315 "Greenville, NC", add
label define metarealbl 316 "Greenville-Spartanburg-Anderson SC", add
label define metarealbl 318 "Hagerstown, MD", add
label define metarealbl 320 "Hamilton-Middleton, OH", add
label define metarealbl 324 "Harrisburg-Lebanon--Carlisle, PA", add
label define metarealbl 328 "Hartford-Bristol-Middleton- New Britain, CT", add
label define metarealbl 329 "Hickory-Morgantown, NC", add
label define metarealbl 330 "Hattiesburg, MS", add
label define metarealbl 332 "Honolulu, HI", add
label define metarealbl 335 "Houma-Thibodoux, LA", add
label define metarealbl 336 "Houston-Brazoria, TX", add
label define metarealbl 340 "Huntington-Ashland, WV/KY/OH", add
label define metarealbl 344 "Huntsville, AL", add
label define metarealbl 348 "Indianapolis, IN", add
label define metarealbl 350 "Iowa City, IA", add
label define metarealbl 352 "Jackson, MI", add
label define metarealbl 356 "Jackson, MS", add
label define metarealbl 358 "Jackson, TN", add
label define metarealbl 359 "Jacksonville, FL", add
label define metarealbl 360 "Jacksonville, NC", add
label define metarealbl 361 "Jamestown-Dunkirk, NY", add
label define metarealbl 362 "Janesville-Beloit, WI", add
label define metarealbl 366 "Johnson City-Kingsport--Bristol, TN/VA", add
label define metarealbl 368 "Johnstown, PA", add
label define metarealbl 371 "Joplin, MO", add
label define metarealbl 372 "Kalamazoo-Portage, MI", add
label define metarealbl 374 "Kankakee, IL", add
label define metarealbl 376 "Kansas City, MO-KS", add
label define metarealbl 380 "Kenosha, WI", add
label define metarealbl 381 "Kileen-Temple, TX", add
label define metarealbl 384 "Knoxville, TN", add
label define metarealbl 385 "Kokomo, IN", add
label define metarealbl 387 "LaCrosse, WI", add
label define metarealbl 388 "Lafayette, LA", add
label define metarealbl 392 "Lafayette-W. Lafayette, IN", add
label define metarealbl 396 "Lake Charles, LA", add
label define metarealbl 398 "Lakeland-Winterhaven, FL", add
label define metarealbl 400 "Lancaster, PA", add
label define metarealbl 404 "Lansing-E. Lansing, MI", add
label define metarealbl 408 "Laredo, TX", add
label define metarealbl 410 "Las Cruces, NM", add
label define metarealbl 412 "Las Vegas, NV", add
label define metarealbl 415 "Lawrence, KS", add
label define metarealbl 420 "Lawton, OK", add
label define metarealbl 424 "Lewiston-Auburn, ME", add
label define metarealbl 428 "Lexington-Fayette, KY", add
label define metarealbl 432 "Lima, OH", add
label define metarealbl 436 "Lincoln, NE", add
label define metarealbl 440 "Little Rock--North Little Rock, AR", add
label define metarealbl 441 "Long Branch-Asbury Park,NJ", add
label define metarealbl 442 "Longview-Marshall, TX", add
label define metarealbl 444 "Lorain-Elyria, OH", add
label define metarealbl 448 "Los Angeles-Long Beach, CA", add
label define metarealbl 452 "Louisville, KY/IN", add
label define metarealbl 460 "Lubbock, TX", add
label define metarealbl 464 "Lynchburg, VA", add
label define metarealbl 468 "Macon-Warner Robins, GA", add
label define metarealbl 472 "Madison, WI", add
label define metarealbl 476 "Manchester, NH", add
label define metarealbl 480 "Mansfield, OH", add
label define metarealbl 488 "McAllen-Edinburg-Pharr-Mission, TX", add
label define metarealbl 489 "Medford, OR", add
label define metarealbl 490 "Melbourne-Titusville-Cocoa-Palm Bay, FL", add
label define metarealbl 492 "Memphis, TN/AR/MS", add
label define metarealbl 494 "Merced, CA", add
label define metarealbl 500 "Miami-Hialeah, FL", add
label define metarealbl 504 "Midland, TX", add
label define metarealbl 508 "Milwaukee, WI", add
label define metarealbl 512 "Minneapolis-St. Paul, MN", add
label define metarealbl 514 "Missoula, MT", add
label define metarealbl 516 "Mobile, AL", add
label define metarealbl 517 "Modesto, CA", add
label define metarealbl 519 "Monmouth-Ocean, NJ", add
label define metarealbl 520 "Monroe, LA", add
label define metarealbl 524 "Montgomery, AL", add
label define metarealbl 528 "Muncie, IN", add
label define metarealbl 532 "Muskegon-Norton Shores-Muskegon Heights, MI", add
label define metarealbl 533 "Myrtle Beach, SC", add
label define metarealbl 534 "Naples, FL", add
label define metarealbl 535 "Nashua, NH", add
label define metarealbl 536 "Nashville, TN", add
label define metarealbl 540 "New Bedford, MA", add
label define metarealbl 546 "New Brunswick-Perth Amboy-Sayreville, NJ", add
label define metarealbl 548 "New Haven-Meriden, CT", add
label define metarealbl 552 "New London-Norwich, CT/RI", add
label define metarealbl 556 "New Orleans, LA", add
label define metarealbl 560 "New York-Northeastern NJ", add
label define metarealbl 564 "Newark, OH", add
label define metarealbl 566 "Newburgh-Middletown, NY", add
label define metarealbl 572 "Norfolk-VA Beach--Newport News, VA", add
label define metarealbl 576 "Norwalk, CT", add
label define metarealbl 579 "Ocala, FL", add
label define metarealbl 580 "Odessa, TX", add
label define metarealbl 588 "Oklahoma City, OK", add
label define metarealbl 591 "Olympia, WA", add
label define metarealbl 592 "Omaha, NE/IA", add
label define metarealbl 595 "Orange, NY", add
label define metarealbl 596 "Orlando, FL", add
label define metarealbl 599 "Owensboro, KY", add
label define metarealbl 601 "Panama City, FL", add
label define metarealbl 602 "Parkersburg-Marietta,WV/OH", add
label define metarealbl 603 "Pascagoula-Moss Point, MS", add
label define metarealbl 608 "Pensacola, FL", add
label define metarealbl 612 "Peoria, IL", add
label define metarealbl 616 "Philadelphia, PA/NJ", add
label define metarealbl 620 "Phoenix, AZ", add
label define metarealbl 628 "Pittsburgh, PA", add
label define metarealbl 632 "Pittsfield, MA", add
label define metarealbl 640 "Portland, ME", add
label define metarealbl 644 "Portland, OR-WA", add
label define metarealbl 645 "Portsmouth-Dover--Rochester, NH/ME", add
label define metarealbl 646 "Poughkeepsie, NY", add
label define metarealbl 648 "Providence-Fall River-Pawtucket, MA/RI", add
label define metarealbl 652 "Provo-Orem, UT", add
label define metarealbl 656 "Pueblo, CO", add
label define metarealbl 658 "Punta Gorda, FL", add
label define metarealbl 660 "Racine, WI", add
label define metarealbl 664 "Raleigh-Durham, NC", add
label define metarealbl 666 "Rapid City, SD", add
label define metarealbl 668 "Reading, PA", add
label define metarealbl 669 "Redding, CA", add
label define metarealbl 672 "Reno, NV", add
label define metarealbl 674 "Richland-Kennewick-Pasco, WA", add
label define metarealbl 676 "Richmond-Petersburg, VA", add
label define metarealbl 678 "Riverside-San Bernadino, CA", add
label define metarealbl 680 "Roanoke, VA", add
label define metarealbl 682 "Rochester, MN", add
label define metarealbl 684 "Rochester, NY", add
label define metarealbl 688 "Rockford, IL", add
label define metarealbl 689 "Rocky Mount, NC", add
label define metarealbl 692 "Sacramento, CA", add
label define metarealbl 696 "Saginaw-Bay City-Midland, MI", add
label define metarealbl 698 "St. Cloud, MN", add
label define metarealbl 700 "St. Joseph, MO", add
label define metarealbl 704 "St. Louis, MO-IL", add
label define metarealbl 708 "Salem, OR", add
label define metarealbl 712 "Salinas-Sea Side-Monterey, CA", add
label define metarealbl 714 "Salisbury-Concord, NC", add
label define metarealbl 716 "Salt Lake City-Ogden, UT", add
label define metarealbl 720 "San Angelo, TX", add
label define metarealbl 724 "San Antonio, TX", add
label define metarealbl 732 "San Diego, CA", add
label define metarealbl 736 "San Francisco-Oakland-Vallejo, CA", add
label define metarealbl 740 "San Jose, CA", add
label define metarealbl 746 "San Luis Obispo-Atascad-P Robles, CA", add
label define metarealbl 747 "Santa Barbara-Santa Maria-Lompoc, CA", add
label define metarealbl 748 "Santa Cruz, CA", add
label define metarealbl 749 "Santa Fe, NM", add
label define metarealbl 750 "Santa Rosa-Petaluma, CA", add
label define metarealbl 751 "Sarasota, FL", add
label define metarealbl 752 "Savannah, GA", add
label define metarealbl 756 "Scranton-Wilkes-Barre, PA", add
label define metarealbl 760 "Seattle-Everett, WA", add
label define metarealbl 761 "Sharon, PA", add
label define metarealbl 762 "Sheboygan, WI", add
label define metarealbl 764 "Sherman-Davidson, TX", add
label define metarealbl 768 "Shreveport, LA", add
label define metarealbl 772 "Sioux City, IA/NE", add
label define metarealbl 776 "Sioux Falls, SD", add
label define metarealbl 780 "South Bend-Mishawaka, IN", add
label define metarealbl 784 "Spokane, WA", add
label define metarealbl 788 "Springfield, IL", add
label define metarealbl 792 "Springfield, MO", add
label define metarealbl 800 "Springfield-Holyoke-Chicopee, MA", add
label define metarealbl 804 "Stamford, CT", add
label define metarealbl 805 "State College, PA", add
label define metarealbl 808 "Steubenville-Weirton,OH/WV", add
label define metarealbl 812 "Stockton, CA", add
label define metarealbl 814 "Sumter, SC", add
label define metarealbl 816 "Syracuse, NY", add
label define metarealbl 820 "Tacoma, WA", add
label define metarealbl 824 "Tallahassee, FL", add
label define metarealbl 828 "Tampa-St. Petersburg-Clearwater, FL", add
label define metarealbl 832 "Terre Haute, IN", add
label define metarealbl 836 "Texarkana, TX/AR", add
label define metarealbl 840 "Toledo, OH/MI", add
label define metarealbl 844 "Topeka, KS", add
label define metarealbl 848 "Trenton, NJ", add
label define metarealbl 852 "Tucson, AZ", add
label define metarealbl 856 "Tulsa, OK", add
label define metarealbl 860 "Tuscaloosa, AL", add
label define metarealbl 864 "Tyler, TX", add
label define metarealbl 868 "Utica-Rome, NY", add
label define metarealbl 873 "Ventura-Oxnard-Simi Valley, CA", add
label define metarealbl 875 "Victoria, TX", add
label define metarealbl 876 "Vineland-Milville-Bridgetown, NJ", add
label define metarealbl 878 "Visalia-Tulare-Porterville, CA", add
label define metarealbl 880 "Waco, TX", add
label define metarealbl 884 "Washington, DC/MD/VA", add
label define metarealbl 888 "Waterbury, CT", add
label define metarealbl 892 "Waterloo-Cedar Falls, IA", add
label define metarealbl 894 "Wausau, WI", add
label define metarealbl 896 "West Palm Beach-Boca Raton-Delray Beach, FL", add
label define metarealbl 900 "Wheeling, WV/OH", add
label define metarealbl 904 "Wichita, KS", add
label define metarealbl 908 "Wichita Falls, TX", add
label define metarealbl 914 "Williamsport, PA", add
label define metarealbl 916 "Wilmington, DE/NJ/MD", add
label define metarealbl 920 "Wilmington, NC", add
label define metarealbl 924 "Worcester, MA", add
label define metarealbl 926 "Yakima, WA", add
label define metarealbl 927 "Yolo, CA", add
label define metarealbl 928 "York, PA", add
label define metarealbl 932 "Youngstown-Warren, OH-PA", add
label define metarealbl 934 "Yuba City, CA", add
label define metarealbl 936 "Yuma, AZ", add
label values metarea metarealbl

label define citylbl 000 "Not in identifiable city (or size group)", add
label define citylbl 001 "Akron, OH", add
label define citylbl 003 "Alameda, CA", add
label define citylbl 005 "Albany, NY", add
label define citylbl 007 "Albuquerque, NM", add
label define citylbl 009 "Alexandria, VA", add
label define citylbl 010 "Alhambra, CA", add
label define citylbl 011 "Allegheny, PA", add
label define citylbl 012 "Aliquippa, PA", add
label define citylbl 013 "Allentown, PA", add
label define citylbl 014 "Alton, IL", add
label define citylbl 015 "Altoona, PA", add
label define citylbl 016 "Amarillo, TX", add
label define citylbl 017 "Amsterdam, NY", add
label define citylbl 019 "Anaheim, CA", add
label define citylbl 021 "Anchorage, AK", add
label define citylbl 023 "Anderson, IN", add
label define citylbl 025 "Andover, MA", add
label define citylbl 027 "Ann Arbor, MI", add
label define citylbl 028 "Appleton, WI", add
label define citylbl 029 "Arlington, TX", add
label define citylbl 031 "Arlington, VA", add
label define citylbl 033 "Asheville, NC", add
label define citylbl 034 "Ashland, KY", add
label define citylbl 035 "Atlanta, GA", add
label define citylbl 037 "Atlantic City, NJ", add
label define citylbl 039 "Auburn, NY", add
label define citylbl 041 "Augusta, GA", add
label define citylbl 043 "Augusta, ME", add
label define citylbl 045 "Aurora, CO", add
label define citylbl 047 "Aurora, IL", add
label define citylbl 049 "Austin, TX", add
label define citylbl 051 "Bakersfield, CA", add
label define citylbl 053 "Baltimore, MD", add
label define citylbl 055 "Bangor, ME", add
label define citylbl 057 "Bath, ME", add
label define citylbl 059 "Baton Rouge, LA", add
label define citylbl 061 "Battle Creek, MI", add
label define citylbl 063 "Bay City, MI", add
label define citylbl 064 "Bayamon, PR", add
label define citylbl 065 "Bayonne, NJ", add
label define citylbl 066 "Belleville, IL", add
label define citylbl 067 "Beaumont, TX", add
label define citylbl 068 "Bellevue, WA", add
label define citylbl 069 "Bellingham, WA", add
label define citylbl 070 "Belleville, NJ", add
label define citylbl 071 "Berkeley, CA", add
label define citylbl 072 "Berwyn, IL", add
label define citylbl 073 "Bethlehem, PA", add
label define citylbl 074 "Biddeford, ME", add
label define citylbl 075 "Binghamton, NY", add
label define citylbl 076 "Beverly, MA", add
label define citylbl 077 "Birmingham, AL", add
label define citylbl 078 "Bloomfield, NJ", add
label define citylbl 079 "Bloomington, IL", add
label define citylbl 080 "Boise, ID", add
label define citylbl 081 "Boston, MA", add
label define citylbl 083 "Bridgeport, CT", add
label define citylbl 085 "Brockton, MA", add
label define citylbl 087 "Brookline, MA", add
label define citylbl 088 "Brownsville, TX", add
label define citylbl 089 "Buffalo, NY", add
label define citylbl 090 "Burlington, IA", add
label define citylbl 091 "Butte, MT", add
label define citylbl 092 "Burbank, CA", add
label define citylbl 093 "Cambridge, MA", add
label define citylbl 095 "Camden, NJ", add
label define citylbl 097 "Camden, NY", add
label define citylbl 099 "Canton, OH", add
label define citylbl 100 "Cape Coral, FL", add
label define citylbl 101 "Cedar Rapids, IA", add
label define citylbl 102 "Central Falls, RI", add
label define citylbl 103 "Charlestown, MA", add
label define citylbl 105 "Charleston, SC", add
label define citylbl 106 "Carolina, PR", add
label define citylbl 107 "Charleston, WV", add
label define citylbl 109 "Charlotte, NC", add
label define citylbl 111 "Chattanooga, TN", add
label define citylbl 113 "Chelsea, MA", add
label define citylbl 115 "Chesapeake, VA", add
label define citylbl 117 "Chester, PA", add
label define citylbl 119 "Chicago, IL", add
label define citylbl 121 "Chicopee, MA", add
label define citylbl 123 "Chillicothe, OH", add
label define citylbl 125 "Chula Vista, CA", add
label define citylbl 127 "Cicero, IL", add
label define citylbl 129 "Cincinnati, OH", add
label define citylbl 131 "Clarksburg, WV", add
label define citylbl 133 "Cleveland, OH", add
label define citylbl 134 "Cleveland Heights, OH", add
label define citylbl 135 "Clifton, NJ", add
label define citylbl 137 "Clinton, IA", add
label define citylbl 139 "Colorado Springs, CO", add
label define citylbl 140 "Cohoes, NY", add
label define citylbl 141 "Columbia, SC", add
label define citylbl 142 "ColumbiaCity, IN", add
label define citylbl 143 "Columbus, GA", add
label define citylbl 145 "Columbus, OH", add
label define citylbl 147 "Concord, CA", add
label define citylbl 149 "Concord, NH", add
label define citylbl 150 "Corona, CA", add
label define citylbl 151 "Council Bluffs, IA", add
label define citylbl 152 "Corpus Christi, TX", add
label define citylbl 153 "Covington, KY", add
label define citylbl 154 "Costa Mesa, CA", add
label define citylbl 155 "Cranston, RI", add
label define citylbl 157 "Cumberland, MD", add
label define citylbl 159 "Dallas, TX", add
label define citylbl 161 "Danvers, MA", add
label define citylbl 163 "Danville, IL", add
label define citylbl 165 "Davenport, IA", add
label define citylbl 167 "Dayton, OH", add
label define citylbl 168 "Dearborn, MI", add
label define citylbl 169 "Decatur, IL", add
label define citylbl 171 "Denver, CO", add
label define citylbl 173 "Des Moines, IA", add
label define citylbl 175 "Detroit, MI", add
label define citylbl 177 "Dorchester, MA", add
label define citylbl 179 "Dover, NH", add
label define citylbl 180 "Downey, CA", add
label define citylbl 181 "Dubuque, IA", add
label define citylbl 183 "Duluth, MN", add
label define citylbl 185 "Durham, NC", add
label define citylbl 187 "East Chicago, IN", add
label define citylbl 189 "East Cleveland, OH", add
label define citylbl 191 "East Los Angeles, CA", add
label define citylbl 193 "East Orange, NJ", add
label define citylbl 194 "East Saginaw, MI", add
label define citylbl 195 "East St. Louis, IL", add
label define citylbl 197 "Easton, PA", add
label define citylbl 199 "El Monte, CA", add
label define citylbl 201 "El Paso, TX", add
label define citylbl 203 "Elgin, IL", add
label define citylbl 204 "Elyria, OH", add
label define citylbl 205 "Elizabeth, NJ", add
label define citylbl 206 "Elkhart, IN", add
label define citylbl 207 "Elmira, NY", add
label define citylbl 208 "Enid, OK", add
label define citylbl 209 "Erie, PA", add
label define citylbl 211 "Escondido, CA", add
label define citylbl 213 "Eugene, OR", add
label define citylbl 215 "Evanston, IL", add
label define citylbl 217 "Evansville, IN", add
label define citylbl 219 "Everett, MA", add
label define citylbl 221 "Everett, WA", add
label define citylbl 222 "Fargo, ND", add
label define citylbl 223 "Fall River, MA", add
label define citylbl 224 "Fayetteville, NC", add
label define citylbl 225 "Fitchburg, MA", add
label define citylbl 226 "Fontana, CA", add
label define citylbl 227 "Flint, MI", add
label define citylbl 228 "Fond du Lac, WI", add
label define citylbl 229 "Fort Lauderdale, FL", add
label define citylbl 230 "Fort Collins, CO", add
label define citylbl 231 "Fort Smith, AR", add
label define citylbl 233 "Fort Wayne, IN", add
label define citylbl 235 "Fort Worth, TX", add
label define citylbl 237 "Fresno, CA", add
label define citylbl 239 "Fullerton, CA", add
label define citylbl 240 "Galesburg, IL", add
label define citylbl 241 "Galveston, TX", add
label define citylbl 243 "Garden Grove, CA", add
label define citylbl 244 "Garfield, NJ", add
label define citylbl 245 "Garland, TX", add
label define citylbl 247 "Gary, IN", add
label define citylbl 249 "Glendale, CA", add
label define citylbl 251 "Gloucester, MA", add
label define citylbl 252 "Granite City, IL", add
label define citylbl 253 "Grand Rapids, MI", add
label define citylbl 254 "Great Falls, MT", add
label define citylbl 255 "Green Bay, WI", add
label define citylbl 257 "Greensboro, NC", add
label define citylbl 258 "Guynabo, PR", add
label define citylbl 259 "Hagerstown, MD", add
label define citylbl 261 "Hamilton, OH", add
label define citylbl 263 "Hammond, IN", add
label define citylbl 265 "Hampton, VA", add
label define citylbl 267 "Hamtramck Village, MI", add
label define citylbl 268 "Hannibal, MO", add
label define citylbl 269 "Harrisburg, PA", add
label define citylbl 271 "Hartford, CT", add
label define citylbl 273 "Haverhill, MA", add
label define citylbl 275 "Hazleton, PA", add
label define citylbl 277 "Hialeah, FL", add
label define citylbl 278 "High Point, NC", add
label define citylbl 279 "Highland Park, MI", add
label define citylbl 281 "Hoboken, NJ", add
label define citylbl 283 "Hollywood, FL", add
label define citylbl 285 "Holyoke, MA", add
label define citylbl 287 "Honolulu, HI", add
label define citylbl 289 "Houston, TX", add
label define citylbl 291 "Huntington, WV", add
label define citylbl 293 "Huntingon Beach, CA", add
label define citylbl 295 "Huntsville, AL", add
label define citylbl 296 "Hutchinson, KS", add
label define citylbl 297 "Independence, MO", add
label define citylbl 299 "Indianapolis, IN", add
label define citylbl 301 "Inglewood, CA", add
label define citylbl 302 "Irvine, CA", add
label define citylbl 303 "Irving, TX", add
label define citylbl 305 "Irvington, NJ", add
label define citylbl 307 "Jackson, MI", add
label define citylbl 309 "Jackson, MS", add
label define citylbl 311 "Jacksonville, FL", add
label define citylbl 313 "Jamestown , NY", add
label define citylbl 315 "Jersey City, NJ", add
label define citylbl 316 "Johnson City, TN", add
label define citylbl 317 "Johnstown, PA", add
label define citylbl 319 "Joliet, IL", add
label define citylbl 321 "Joplin, MO", add
label define citylbl 323 "Kalamazoo, MI", add
label define citylbl 325 "Kansas City, KS", add
label define citylbl 326 "Kansas City, MO", add
label define citylbl 327 "Kearny, NJ", add
label define citylbl 329 "Kenosha, WI", add
label define citylbl 331 "Kingston, NY", add
label define citylbl 333 "Knoxville, TN", add
label define citylbl 335 "Kokomo, IN", add
label define citylbl 337 "La Crosse, WI", add
label define citylbl 338 "Lafayette, IL", add
label define citylbl 339 "Lafayette, LA", add
label define citylbl 341 "Lakewood, CO", add
label define citylbl 343 "Lakewood, OH", add
label define citylbl 344 "Lancaster, CA", add
label define citylbl 345 "Lancaster, PA", add
label define citylbl 347 "Lansing, MI", add
label define citylbl 348 "Laredo, TX", add
label define citylbl 349 "Las Vegas, NV", add
label define citylbl 351 "Lawrence, MA", add
label define citylbl 352 "Leavenworth, KS", add
label define citylbl 353 "Lehigh, PA", add
label define citylbl 354 "Lebanon, PA", add
label define citylbl 355 "Lewiston, ME", add
label define citylbl 357 "Lexington, KY", add
label define citylbl 359 "Lexington-Fayette, KY", add
label define citylbl 361 "Lima, OH", add
label define citylbl 363 "Lincoln, NE", add
label define citylbl 365 "Little Rock, AR", add
label define citylbl 367 "Livonia, MI", add
label define citylbl 368 "Lockport, NY", add
label define citylbl 369 "Long Beach, CA", add
label define citylbl 371 "Lorain, OH", add
label define citylbl 373 "Los Angeles, CA", add
label define citylbl 375 "Louisville, KY", add
label define citylbl 377 "Lowell, MA", add
label define citylbl 379 "Lynchburg, VA", add
label define citylbl 381 "Lynn, MA", add
label define citylbl 383 "Macon, GA", add
label define citylbl 385 "Madison, IN", add
label define citylbl 387 "Madison, WI", add
label define citylbl 389 "Malden, MA", add
label define citylbl 391 "Manchester, NH", add
label define citylbl 393 "Mansfield, OH", add
label define citylbl 394 "Maywood, IL", add
label define citylbl 395 "Marion, OH", add
label define citylbl 396 "McAllen, TX", add
label define citylbl 397 "McKeesport, PA", add
label define citylbl 399 "Medford, MA", add
label define citylbl 401 "Memphis, TN", add
label define citylbl 403 "Meriden, CT", add
label define citylbl 404 "Meridian, MS", add
label define citylbl 405 "Mesa, AZ", add
label define citylbl 407 "Mesquite, TX", add
label define citylbl 409 "Metairie, LA", add
label define citylbl 411 "Miami, FL", add
label define citylbl 412 "Michigan City, IN", add
label define citylbl 413 "Milwaukee, WI", add
label define citylbl 415 "Minneapolis, MN", add
label define citylbl 416 "Mishawaka, IN", add
label define citylbl 417 "Mobile, AL", add
label define citylbl 419 "Modesto, CA", add
label define citylbl 421 "Moline, IL", add
label define citylbl 423 "Montclair, NJ", add
label define citylbl 425 "Montgomery, AL", add
label define citylbl 427 "Moreno Valley, CA", add
label define citylbl 429 "Mount Vernon, NY", add
label define citylbl 431 "Muncie, IN", add
label define citylbl 433 "Muskegon, MI", add
label define citylbl 435 "Muskogee, OK", add
label define citylbl 437 "Nantucket, MA", add
label define citylbl 439 "Nashua, NH", add
label define citylbl 441 "Nashville-Davidson, TN", add
label define citylbl 443 "New Albany, IN", add
label define citylbl 445 "New Bedford, MA", add
label define citylbl 447 "New Britain, CT", add
label define citylbl 449 "New Brunswick, NJ", add
label define citylbl 451 "New Castle, PA", add
label define citylbl 453 "New Haven, CT", add
label define citylbl 455 "New London, CT", add
label define citylbl 457 "New Orleans, LA", add
label define citylbl 459 "New Rochelle, NY", add
label define citylbl 461 "New York, NY", add
label define citylbl 463 "Newark, NJ", add
label define citylbl 465 "Newark, OH", add
label define citylbl 467 "Newburgh, NY", add
label define citylbl 469 "Newburyport, MA", add
label define citylbl 471 "Newport, KY", add
label define citylbl 473 "Newport, RI", add
label define citylbl 475 "Newport News, VA", add
label define citylbl 477 "Newton, MA", add
label define citylbl 479 "Niagara Falls, NY", add
label define citylbl 481 "Norfolk, VA", add
label define citylbl 482 "North Las Vegas, NV", add
label define citylbl 483 "Norristown Borough, PA", add
label define citylbl 484 "Northampton, MA", add
label define citylbl 485 "North Providence, RI", add
label define citylbl 486 "Norwalk, CA", add
label define citylbl 487 "Norwalk, CT", add
label define citylbl 489 "Norwich, CT", add
label define citylbl 490 "Norwood, OH", add
label define citylbl 491 "Oak Park Village", add
label define citylbl 493 "Oakland, CA", add
label define citylbl 495 "Oceanside, CA", add
label define citylbl 497 "Ogden, UT", add
label define citylbl 499 "Oklahoma City, OK", add
label define citylbl 501 "Omaha, NE", add
label define citylbl 503 "Ontario, CA", add
label define citylbl 504 "Orange, CA", add
label define citylbl 505 "Orange, NJ", add
label define citylbl 507 "Orlando, FL", add
label define citylbl 509 "Oshkosh, WI", add
label define citylbl 511 "Oswego, NY", add
label define citylbl 513 "Oxnard, CA", add
label define citylbl 514 "Palmdale, CA", add
label define citylbl 515 "Pasadena, CA", add
label define citylbl 517 "Pasadena, TX", add
label define citylbl 518 "Paducah, KY", add
label define citylbl 519 "Passaic, NJ", add
label define citylbl 521 "Paterson, NJ", add
label define citylbl 523 "Pawtucket, RI", add
label define citylbl 525 "Pensacola, FL (1920)", add
label define citylbl 527 "Peoria, IL", add
label define citylbl 529 "Perth Amboy, NJ", add
label define citylbl 531 "Petersburg, VA", add
label define citylbl 533 "Philadelphia, PA", add
label define citylbl 535 "Phoenix, AZ", add
label define citylbl 537 "Pittsburgh, PA", add
label define citylbl 539 "Pittsfield, MA", add
label define citylbl 541 "Plainfield, NJ", add
label define citylbl 543 "Plano, TX", add
label define citylbl 545 "Pomona, CA", add
label define citylbl 546 "Ponce, PR", add
label define citylbl 547 "Pontiac, MI", add
label define citylbl 548 "Port Arthur, TX", add
label define citylbl 549 "Port Huron, MI", add
label define citylbl 551 "Portland, ME", add
label define citylbl 553 "Portland, OR", add
label define citylbl 555 "Portsmouth, NH", add
label define citylbl 557 "Portsmouth, OH", add
label define citylbl 559 "Portsmouth, VA", add
label define citylbl 561 "Pottsville, PA", add
label define citylbl 563 "Poughkeepsie, NY", add
label define citylbl 565 "Providence, RI", add
label define citylbl 566 "Provo, UT", add
label define citylbl 567 "Pueblo, CO", add
label define citylbl 569 "Quincy, IL", add
label define citylbl 571 "Quincy, MA", add
label define citylbl 573 "Racine, WI", add
label define citylbl 575 "Raleigh, NC", add
label define citylbl 577 "Rancho Cucamonga, CA", add
label define citylbl 579 "Reading, PA", add
label define citylbl 581 "Reno, NV", add
label define citylbl 583 "Revere, MA", add
label define citylbl 585 "Richmond, IN", add
label define citylbl 587 "Richmond, VA", add
label define citylbl 589 "Riverside, CA", add
label define citylbl 591 "Roanoke, VA", add
label define citylbl 593 "Rochester, NY", add
label define citylbl 595 "Rock Island, IL", add
label define citylbl 597 "Rockford, IL", add
label define citylbl 599 "Rome, NY", add
label define citylbl 601 "Roxbury, MA", add
label define citylbl 603 "Sacramento, CA", add
label define citylbl 605 "Saginaw, MI", add
label define citylbl 607 "Saint Joseph, MO", add
label define citylbl 609 "Saint Louis, MO", add
label define citylbl 611 "Saint Paul, MN", add
label define citylbl 613 "Saint Petersburg, FL", add
label define citylbl 615 "Salem, MA", add
label define citylbl 617 "Salem, OR", add
label define citylbl 619 "Salinas, CA", add
label define citylbl 621 "Salt Lake City, UT", add
label define citylbl 622 "San Angelo, TX", add
label define citylbl 623 "San Antonio, TX", add
label define citylbl 625 "San Bernadino, CA", add
label define citylbl 626 "San Buenaventura (Ventura), CA", add
label define citylbl 627 "San Diego, CA", add
label define citylbl 628 "Sandusky, OH", add
label define citylbl 629 "San Francisco, CA", add
label define citylbl 630 "San Juan, PR", add
label define citylbl 631 "San Jose, CA", add
label define citylbl 632 "Santa Barbara, CA", add
label define citylbl 633 "Santa Ana, CA", add
label define citylbl 634 "Santa Clarita, CA", add
label define citylbl 635 "Santa Rosa, CA", add
label define citylbl 636 "Santa Monica, CA", add
label define citylbl 637 "Savannah, GA", add
label define citylbl 639 "Schenectedy, NY", add
label define citylbl 641 "Scranton, PA", add
label define citylbl 643 "Seattle, WA", add
label define citylbl 644 "Sharon, PA", add
label define citylbl 645 "Sheboygan, WI", add
label define citylbl 647 "Shenandoah Borough, PA", add
label define citylbl 649 "Shreveport, LA", add
label define citylbl 650 "Simi Valley, CA", add
label define citylbl 651 "Sioux City, IA", add
label define citylbl 653 "Sioux Falls, SD", add
label define citylbl 655 "Smithfield, RI (1850)", add
label define citylbl 657 "Somerville, MA", add
label define citylbl 659 "South Bend, IN", add
label define citylbl 661 "South Omaha, NE", add
label define citylbl 662 "Spartanburg, SC", add
label define citylbl 663 "Spokane, WA", add
label define citylbl 665 "Springfield, IL", add
label define citylbl 667 "Springfield, MA", add
label define citylbl 669 "Springfield, MO", add
label define citylbl 671 "Springfield, OH", add
label define citylbl 673 "Stamford, CT", add
label define citylbl 675 "Sterling Heights, MI", add
label define citylbl 677 "Steubenville, OH", add
label define citylbl 679 "Stockton, CA", add
label define citylbl 681 "Sunnyvale, CA", add
label define citylbl 683 "Superior, WI", add
label define citylbl 685 "Syracuse, NY", add
label define citylbl 687 "Tacoma, WA", add
label define citylbl 689 "Tampa, FL", add
label define citylbl 691 "Taunton, MA", add
label define citylbl 693 "Tempe, AZ", add
label define citylbl 695 "Terre Haute, IN", add
label define citylbl 696 "Thousand Oaks, CA", add
label define citylbl 697 "Toledo, OH", add
label define citylbl 699 "Topeka, KS", add
label define citylbl 700 "Torrance, CA", add
label define citylbl 701 "Trenton, NJ", add
label define citylbl 703 "Troy, NY", add
label define citylbl 705 "Tucson, AZ", add
label define citylbl 707 "Tulsa, OK", add
label define citylbl 708 "Union City, NJ", add
label define citylbl 709 "Utica, NY", add
label define citylbl 710 "Vancouver, WA", add
label define citylbl 711 "Vallejo, CA", add
label define citylbl 712 "Vicksburg, MS", add
label define citylbl 713 "Virginia Beach, VA", add
label define citylbl 714 "University City, MO", add
label define citylbl 715 "Waco, TX", add
label define citylbl 717 "Waltham, MA", add
label define citylbl 718 "Warren, MI", add
label define citylbl 719 "Warren, OH", add
label define citylbl 721 "Warwick Town, RI", add
label define citylbl 723 "Washington, DC", add
label define citylbl 724 "Waukegan, IL", add
label define citylbl 725 "Waterbury, CT", add
label define citylbl 727 "Waterloo, IA", add
label define citylbl 729 "Waterloo, NY", add
label define citylbl 731 "Watertown, NY", add
label define citylbl 732 "West Covina, CA", add
label define citylbl 733 "West Hoboken, NJ", add
label define citylbl 734 "West Allis, WI", add
label define citylbl 735 "West New York, NJ", add
label define citylbl 737 "West Troy, NY", add
label define citylbl 739 "Wheeling, WV", add
label define citylbl 740 "White Plains, NY", add
label define citylbl 741 "Wichita, KS", add
label define citylbl 743 "Wichita Falls, TX", add
label define citylbl 745 "Wilkes-Barre, PA", add
label define citylbl 746 "Wilkinsburg, PA", add
label define citylbl 747 "Williamsport, PA", add
label define citylbl 749 "Wilmington, DE", add
label define citylbl 751 "Wilmington, NC", add
label define citylbl 753 "Winston-Salem, NC", add
label define citylbl 755 "Woonsocket, RI", add
label define citylbl 757 "Worcester, MA", add
label define citylbl 759 "Yonkers, NY", add
label define citylbl 761 "York, PA", add
label define citylbl 763 "Youngstown, OH", add
label define citylbl 765 "Zanesville, OH", add
label define citylbl 810 "City 20,000-24,999", add
label define citylbl 811 "City 10,000-19,999", add
label define citylbl 812 "City 10,000 - 24,999", add
label define citylbl 820 "City 8,000-9,999", add
label define citylbl 830 "City 5,000-7,999", add
label define citylbl 840 "City 4,000-4,999", add
label define citylbl 850 "City 2,500-3,999", add
label define citylbl 860 "City 1,000-2,499", add
label define citylbl 870 "Under 1,000, incorporated", add
label define citylbl 880 "Under 1,000, unincorporated", add
label define citylbl 881 "Military Reservation", add
label define citylbl 882 "Indian Reservation", add
label values city citylbl

label values citypop citypoplbl

label define sizepllbl 00 "Not identifiable"
label define sizepllbl 01 "Under 1,000, or unincorporated", add
label define sizepllbl 02 "1,000 - 2,499", add
label define sizepllbl 03 "2,500 - 3,999", add
label define sizepllbl 04 "4,000 - 4,999", add
label define sizepllbl 05 "5,000 - 9,999", add
label define sizepllbl 06 "10,000 - 24,999", add
label define sizepllbl 07 "25,000 - 49,999", add
label define sizepllbl 08 "50,000 - 74,999", add
label define sizepllbl 09 "75,000 - 99,999", add
label define sizepllbl 10 "100,000 - 199,999", add
label define sizepllbl 20 "200,000 - 299,999", add
label define sizepllbl 30 "300,000 - 399,999", add
label define sizepllbl 40 "400,000 - 499,999", add
label define sizepllbl 50 "500,000 - 599,999", add
label define sizepllbl 60 "600,000 - 749,999", add
label define sizepllbl 70 "750,000 - 999,999", add
label define sizepllbl 80 "1,000,000 - 1,999,999", add
label define sizepllbl 90 "2,000,000+", add
label values sizepl sizepllbl

label values puma pumalbl

label define pumatypelbl 10 "Central city", add
label define pumatypelbl 11 "Central city part", add
label define pumatypelbl 20 "MSA/PMSA - outside central city", add
label define pumatypelbl 21 "MSA/PMSA - outside central city part 21", add
label define pumatypelbl 22 "Central city (part) and outside central city (part)", add
label define pumatypelbl 30 "Entire MSA", add
label define pumatypelbl 31 "2 or more MSAs/PMSAs", add
label define pumatypelbl 40 "Mixed MSA/PMSA/non-MSA/PMSA", add
label define pumatypelbl 50 "Outside MSA/PMSA", add
label define pumatypelbl 60 "Census designated place", add
label define pumatypelbl 61 "Place - part", add
label define pumatypelbl 70 "Minor Civil Divisions/towns", add
label define pumatypelbl 80 "Counties/independent cities (2 or more)", add
label define pumatypelbl 81 "County/independent city - part", add
label define pumatypelbl 82 "County/independent city", add
label values pumatype pumatypelbl

label define gqlbl 0 "Vacant unit", add
label define gqlbl 1 "Households under 1970 definition", add
label define gqlbl 2 "Additional households under 1990 definition", add
label define gqlbl 3 "Group quarters--Institutions", add
label define gqlbl 4 "Other group quarters", add
label define gqlbl 5 "Additional households under 2000 definition", add
label define gqlbl 6 "Fragment", add
label values gq gqlbl

label values pernum pernumlbl

label values perwt perwtlbl

label define momloclbl 00 "00"
label define momloclbl 01 "01", add
label define momloclbl 02 "02", add
label define momloclbl 03 "03", add
label define momloclbl 04 "04", add
label define momloclbl 05 "05", add
label define momloclbl 06 "06", add
label define momloclbl 07 "07", add
label define momloclbl 08 "08", add
label define momloclbl 09 "09", add
label define momloclbl 10 "10", add
label define momloclbl 11 "11", add
label define momloclbl 12 "12", add
label define momloclbl 13 "13", add
label define momloclbl 14 "14", add
label define momloclbl 15 "15", add
label define momloclbl 16 "16", add
label define momloclbl 17 "17", add
label define momloclbl 18 "18", add
label define momloclbl 19 "19", add
label define momloclbl 20 "20", add
label define momloclbl 21 "21", add
label define momloclbl 22 "22", add
label define momloclbl 23 "23", add
label define momloclbl 24 "24", add
label define momloclbl 25 "25", add
label define momloclbl 26 "26", add
label define momloclbl 27 "27", add
label define momloclbl 28 "28", add
label define momloclbl 29 "29", add
label values momloc momloclbl

label define stepmomlbl 0 "No stepmother present"
label define stepmomlbl 1 "Improbable age difference", add
label define stepmomlbl 2 "Spouse of father", add
label define stepmomlbl 3 "Identified stepmother", add
label define stepmomlbl 4 "No surviving children", add
label define stepmomlbl 5 "Identified as adopted", add
label define stepmomlbl 6 "Birthplace/marriage duration mismatch", add
label define stepmomlbl 7 "Number of children born/children surviving check", add
label values stepmom stepmomlbl

label define momrulelbl 0 "No mother link"
label define momrulelbl 1 "Unambiguous mother link", add
label define momrulelbl 2 "Daughter/grandchild link", add
label define momrulelbl 3 "Preceding female (no intervening person)", add
label define momrulelbl 4 "Preceding female (surname similarity)", add
label define momrulelbl 5 "Daughter/grandchild (child surviving status)", add
label define momrulelbl 6 "Preceding female (child surviving status)", add
label define momrulelbl 7 "Spouse of father becomes stepmother", add
label values momrule momrulelbl

label define poploclbl 00 "00"
label define poploclbl 01 "01", add
label define poploclbl 02 "02", add
label define poploclbl 03 "03", add
label define poploclbl 04 "04", add
label define poploclbl 05 "05", add
label define poploclbl 06 "06", add
label define poploclbl 07 "07", add
label define poploclbl 08 "08", add
label define poploclbl 09 "09", add
label define poploclbl 10 "10", add
label define poploclbl 11 "11", add
label define poploclbl 12 "12", add
label define poploclbl 13 "13", add
label define poploclbl 14 "14", add
label define poploclbl 15 "15", add
label define poploclbl 16 "16", add
label define poploclbl 17 "17", add
label define poploclbl 18 "18", add
label define poploclbl 19 "19", add
label define poploclbl 20 "20", add
label define poploclbl 21 "21", add
label define poploclbl 22 "22", add
label define poploclbl 23 "23", add
label define poploclbl 24 "24", add
label define poploclbl 25 "25", add
label define poploclbl 26 "26", add
label define poploclbl 27 "27", add
label define poploclbl 28 "28", add
label define poploclbl 29 "29", add
label values poploc poploclbl

label define steppoplbl 0 "No stepfather present"
label define steppoplbl 1 "Improbable age difference", add
label define steppoplbl 2 "Spouse of mother", add
label define steppoplbl 3 "Identified stepfather", add
label define steppoplbl 5 "Identified as adopted", add
label define steppoplbl 6 "Birthplace/marriage duration mismatch", add
label define steppoplbl 7 "Surname difference -- male child or never-married female", add
label values steppop steppoplbl

label define poprulelbl 0 "No father link"
label define poprulelbl 1 "Unambiguous father link", add
label define poprulelbl 2 "Son/granchild link", add
label define poprulelbl 3 "Preceding male (no intervening person)", add
label define poprulelbl 4 "Preceding male (surname similarity)", add
label define poprulelbl 7 "Husband of mother becomes stepfather", add
label values poprule poprulelbl

label define sploclbl 00 "00"
label define sploclbl 01 "01", add
label define sploclbl 02 "02", add
label define sploclbl 03 "03", add
label define sploclbl 04 "04", add
label define sploclbl 05 "05", add
label define sploclbl 06 "06", add
label define sploclbl 07 "07", add
label define sploclbl 08 "08", add
label define sploclbl 09 "09", add
label define sploclbl 10 "10", add
label define sploclbl 11 "11", add
label define sploclbl 12 "12", add
label define sploclbl 13 "13", add
label define sploclbl 14 "14", add
label define sploclbl 15 "15", add
label define sploclbl 16 "16", add
label define sploclbl 17 "17", add
label define sploclbl 18 "18", add
label define sploclbl 19 "19", add
label define sploclbl 20 "20", add
label define sploclbl 21 "21", add
label define sploclbl 22 "22", add
label define sploclbl 23 "23", add
label define sploclbl 24 "24", add
label define sploclbl 25 "25", add
label define sploclbl 26 "26", add
label define sploclbl 27 "27", add
label define sploclbl 28 "28", add
label define sploclbl 29 "29", add
label values sploc sploclbl

label define nchildlbl 0 "0 children present"
label define nchildlbl 1 "1 child present", add
label define nchildlbl 2 "2", add
label define nchildlbl 3 "3", add
label define nchildlbl 4 "4", add
label define nchildlbl 5 "5", add
label define nchildlbl 6 "6", add
label define nchildlbl 7 "7", add
label define nchildlbl 8 "8", add
label define nchildlbl 9 "9+", add
label values nchild nchildlbl

label define relatedlbl 0101 "Head/Householder", add
label define relatedlbl 0201 "Spouse", add
label define relatedlbl 0202 "2nd/3rd Wife (Polygamous)", add
label define relatedlbl 0301 "Child", add
label define relatedlbl 0302 "Adopted Child", add
label define relatedlbl 0303 "Stepchild", add
label define relatedlbl 0304 "Adopted, n.s.", add
label define relatedlbl 0401 "Child-in-law", add
label define relatedlbl 0402 "Step Child-in-law", add
label define relatedlbl 0501 "Parent", add
label define relatedlbl 0502 "Stepparent", add
label define relatedlbl 0601 "Parent-in-Law", add
label define relatedlbl 0602 "Stepparent-in-law", add
label define relatedlbl 0701 "Sibling", add
label define relatedlbl 0702 "Step/Half/Adopted Sibling", add
label define relatedlbl 0801 "Sibling-in-Law", add
label define relatedlbl 0802 "Step/Half Sibling-in-law", add
label define relatedlbl 0901 "Grandchild", add
label define relatedlbl 0902 "Adopted Grandchild", add
label define relatedlbl 0903 "Step Grandchild", add
label define relatedlbl 0904 "Grandchild-in-law", add
label define relatedlbl 1000 "Other Relatives:", add
label define relatedlbl 1001 "Other Relatives", add
label define relatedlbl 1011 "Grandparent", add
label define relatedlbl 1012 "Step Grandparent", add
label define relatedlbl 1013 "Grandparent-in-law", add
label define relatedlbl 1021 "Aunt or Uncle", add
label define relatedlbl 1022 "Aunt,Uncle-in-law", add
label define relatedlbl 1031 "Nephew, Niece", add
label define relatedlbl 1032 "Neph/Niece-in-law", add
label define relatedlbl 1033 "Step/Adopted Nephew/Niece", add
label define relatedlbl 1034 "Grand Niece/Nephew", add
label define relatedlbl 1041 "Cousin", add
label define relatedlbl 1042 "Cousin-in-law", add
label define relatedlbl 1051 "Great Grandchild", add
label define relatedlbl 1061 "Other relatives, nec", add
label define relatedlbl 1100 "Partner, Friend, Visitor", add
label define relatedlbl 1110 "Partner/friend", add
label define relatedlbl 1111 "Friend", add
label define relatedlbl 1112 "Partner", add
label define relatedlbl 1113 "Partner/roommate", add
label define relatedlbl 1114 "Unmarried Partner", add
label define relatedlbl 1115 "Housemate/Roomate", add
label define relatedlbl 1120 "Relative of partner", add
label define relatedlbl 1130 "Concubine/Mistress", add
label define relatedlbl 1131 "Visitor", add
label define relatedlbl 1132 "Companion and family of companion", add
label define relatedlbl 1139 "Allocated partner/friend/visitor", add
label define relatedlbl 1200 "Other non-relatives", add
label define relatedlbl 1201 "Roomers/boarders/lodgers", add
label define relatedlbl 1202 "Boarders", add
label define relatedlbl 1203 "Lodgers", add
label define relatedlbl 1204 "Roomer", add
label define relatedlbl 1205 "Tenant", add
label define relatedlbl 1206 "Foster child", add
label define relatedlbl 1210 "Employees:", add
label define relatedlbl 1211 "Servant", add
label define relatedlbl 1212 "Housekeeper", add
label define relatedlbl 1213 "Maid", add
label define relatedlbl 1214 "Cook", add
label define relatedlbl 1215 "Nurse", add
label define relatedlbl 1216 "Other probable domestic employee", add
label define relatedlbl 1217 "Other employee", add
label define relatedlbl 1219 "Relative of employee", add
label define relatedlbl 1221 "Military", add
label define relatedlbl 1222 "Students", add
label define relatedlbl 1223 "Members of religious orders", add
label define relatedlbl 1230 "Other non-relatives", add
label define relatedlbl 1239 "Allocated other non-relative", add
label define relatedlbl 1240 "Roomers/boarders/lodgers and foster children", add
label define relatedlbl 1241 "Roomers/boarders/lodgers", add
label define relatedlbl 1242 "Foster children", add
label define relatedlbl 1250 "Employees", add
label define relatedlbl 1251 "Domestic employees", add
label define relatedlbl 1252 "Non-domestic employees", add
label define relatedlbl 1253 "Relative of employee", add
label define relatedlbl 1260 "Other non-relatives (1990 includes employees)", add
label define relatedlbl 1270 "Non-inmate 1990", add
label define relatedlbl 1281 "Head of group quarters", add
label define relatedlbl 1282 "Employees of group quarters", add
label define relatedlbl 1283 "Relative of head, staff, or employee group quarters", add
label define relatedlbl 1284 "Other non-inmate 1940-1959", add
label define relatedlbl 1291 "Military", add
label define relatedlbl 1292 "College dormitories", add
label define relatedlbl 1293 "Residents of rooming houses", add
label define relatedlbl 1294 "Other non-inmate 1980 (includes employees and non-inmates in", add
label define relatedlbl 1295 "Other non-inmates 1960-1970 (includes employees)", add
label define relatedlbl 1296 "Non-inmates in institutions", add
label define relatedlbl 1301 "Institutional inmates", add
label values related relatedlbl

label define agelbl 000 "Less than 1 year old"
label define agelbl 001 "1", add
label define agelbl 002 "2", add
label define agelbl 003 "3", add
label define agelbl 004 "4", add
label define agelbl 005 "5", add
label define agelbl 006 "6", add
label define agelbl 007 "7", add
label define agelbl 008 "8", add
label define agelbl 009 "9", add
label define agelbl 010 "10", add
label define agelbl 011 "11", add
label define agelbl 012 "12", add
label define agelbl 013 "13", add
label define agelbl 014 "14", add
label define agelbl 015 "15", add
label define agelbl 016 "16", add
label define agelbl 017 "17", add
label define agelbl 018 "18", add
label define agelbl 019 "19", add
label define agelbl 020 "20", add
label define agelbl 021 "21", add
label define agelbl 022 "22", add
label define agelbl 023 "23", add
label define agelbl 024 "24", add
label define agelbl 025 "25", add
label define agelbl 026 "26", add
label define agelbl 027 "27", add
label define agelbl 028 "28", add
label define agelbl 029 "29", add
label define agelbl 030 "30", add
label define agelbl 031 "31", add
label define agelbl 032 "32", add
label define agelbl 033 "33", add
label define agelbl 034 "34", add
label define agelbl 035 "35", add
label define agelbl 036 "36", add
label define agelbl 037 "37", add
label define agelbl 038 "38", add
label define agelbl 039 "39", add
label define agelbl 040 "40", add
label define agelbl 041 "41", add
label define agelbl 042 "42", add
label define agelbl 043 "43", add
label define agelbl 044 "44", add
label define agelbl 045 "45", add
label define agelbl 046 "46", add
label define agelbl 047 "47", add
label define agelbl 048 "48", add
label define agelbl 049 "49", add
label define agelbl 050 "50", add
label define agelbl 051 "51", add
label define agelbl 052 "52", add
label define agelbl 053 "53", add
label define agelbl 054 "54", add
label define agelbl 055 "55", add
label define agelbl 056 "56", add
label define agelbl 057 "57", add
label define agelbl 058 "58", add
label define agelbl 059 "59", add
label define agelbl 060 "60", add
label define agelbl 061 "61", add
label define agelbl 062 "62", add
label define agelbl 063 "63", add
label define agelbl 064 "64", add
label define agelbl 065 "65", add
label define agelbl 066 "66", add
label define agelbl 067 "67", add
label define agelbl 068 "68", add
label define agelbl 069 "69", add
label define agelbl 070 "70", add
label define agelbl 071 "71", add
label define agelbl 072 "72", add
label define agelbl 073 "73", add
label define agelbl 074 "74", add
label define agelbl 075 "75", add
label define agelbl 076 "76", add
label define agelbl 077 "77", add
label define agelbl 078 "78", add
label define agelbl 079 "79", add
label define agelbl 080 "80", add
label define agelbl 081 "81", add
label define agelbl 082 "82", add
label define agelbl 083 "83", add
label define agelbl 084 "84", add
label define agelbl 085 "85", add
label define agelbl 086 "86", add
label define agelbl 087 "87", add
label define agelbl 088 "88", add
label define agelbl 089 "89", add
label define agelbl 090 "90 (90+ in 1980 and 1990)", add
label define agelbl 091 "91", add
label define agelbl 092 "92", add
label define agelbl 093 "93", add
label define agelbl 094 "94", add
label define agelbl 095 "95", add
label define agelbl 096 "96", add
label define agelbl 097 "97", add
label define agelbl 098 "98", add
label define agelbl 099 "99", add
label define agelbl 100 "100", add
label define agelbl 101 "101", add
label define agelbl 102 "102", add
label define agelbl 103 "103", add
label define agelbl 104 "104", add
label define agelbl 105 "105", add
label define agelbl 106 "106", add
label define agelbl 107 "107", add
label define agelbl 108 "108", add
label define agelbl 109 "109", add
label define agelbl 110 "110", add
label define agelbl 111 "111", add
label define agelbl 112 "112", add
label define agelbl 113 "113", add
label define agelbl 114 "114", add
label define agelbl 115 "115 (115+ in 1990s)", add
label define agelbl 116 "116", add
label define agelbl 117 "117", add
label define agelbl 118 "118", add
label define agelbl 119 "119", add
label define agelbl 120 "120", add
label define agelbl 121 "121", add
label define agelbl 122 "122", add
label define agelbl 123 "123", add
label define agelbl 124 "124", add
label define agelbl 125 "125", add
label define agelbl 126 "126", add
label values age agelbl

label define sexlbl 1 "Male"
label define sexlbl 2 "Female", add
label values sex sexlbl

label define marstlbl 1 "Married, spouse present"
label define marstlbl 2 "Married, spouse absent", add
label define marstlbl 3 "Separated", add
label define marstlbl 4 "Divorced", add
label define marstlbl 5 "Widowed", add
label define marstlbl 6 "Never married/single", add
label values marst marstlbl

label define racelbl 1 "White"
label define racelbl 2 "Black/Negro", add
label define racelbl 3 "American Indian or Alaska Native", add
label define racelbl 4 "Chinese", add
label define racelbl 5 "Japanese", add
label define racelbl 6 "Other Asian or Pacific Islander", add
label define racelbl 7 "Other race, nec", add
label define racelbl 8 "Two major races", add
label define racelbl 9 "Three or more major races", add
label values race racelbl

label define racedlbl 100 "White", add
label define racedlbl 110 "Spanish write-in", add
label define racedlbl 120 "Blank (white) (1850)", add
label define racedlbl 130 "Portuguese", add
label define racedlbl 140 "Mexican (1930)", add
label define racedlbl 150 "Puerto Rican (1910 Hawaii)", add
label define racedlbl 200 "Black/Negro", add
label define racedlbl 210 "Mulatto", add
label define racedlbl 300 "American Indian/Alaska Native", add
label define racedlbl 301 "Alaskan Athabaskan", add
label define racedlbl 302 "Apache", add
label define racedlbl 303 "Blackfoot", add
label define racedlbl 304 "Cherokee", add
label define racedlbl 305 "Cheyenne", add
label define racedlbl 306 "Chickasaw", add
label define racedlbl 307 "Chippewa", add
label define racedlbl 308 "Choctaw", add
label define racedlbl 309 "Comanche", add
label define racedlbl 310 "Creek", add
label define racedlbl 311 "Crow", add
label define racedlbl 312 "Iroquois", add
label define racedlbl 313 "Kiowa", add
label define racedlbl 314 "Lumbee", add
label define racedlbl 315 "Navajo", add
label define racedlbl 316 "Osage", add
label define racedlbl 317 "Paiute", add
label define racedlbl 318 "Pima", add
label define racedlbl 319 "Potawatomi", add
label define racedlbl 320 "Pueblo", add
label define racedlbl 321 "Seminole", add
label define racedlbl 322 "Shoshone", add
label define racedlbl 323 "Sioux", add
label define racedlbl 324 "Tlingit (Tlingit-Haida, 2000/ACS)", add
label define racedlbl 325 "Tohono O Odham", add
label define racedlbl 326 "All other tribes (1990)", add
label define racedlbl 327 "Tribe not specified", add
label define racedlbl 330 "Aleut", add
label define racedlbl 340 "Eskimo", add
label define racedlbl 341 "Alaskan mixed", add
label define racedlbl 350 "Delaware", add
label define racedlbl 351 "Latin American Indian", add
label define racedlbl 352 "Puget Sound Salish", add
label define racedlbl 353 "Yakama", add
label define racedlbl 354 "Yaqui", add
label define racedlbl 355 "Colville", add
label define racedlbl 356 "Houma", add
label define racedlbl 357 "Menominee", add
label define racedlbl 358 "Yuman", add
label define racedlbl 390 "Other Amer. Indian tribe (2000,ACS)", add
label define racedlbl 391 "2+ Amer. Indian tribes (2000,ACS)", add
label define racedlbl 392 "Other Alaska Native tribe(s) (2000,ACS)", add
label define racedlbl 393 "Both Am. Ind. and Alaska Native (2000,ACS)", add
label define racedlbl 400 "Chinese", add
label define racedlbl 410 "Taiwanese", add
label define racedlbl 420 "Chinese and Taiwanese", add
label define racedlbl 500 "Japanese", add
label define racedlbl 600 "Filipino", add
label define racedlbl 610 "Asian Indian (Hindu 1920-1940)", add
label define racedlbl 620 "Korean", add
label define racedlbl 630 "Hawaiian", add
label define racedlbl 631 "Hawaiian and Asian (1900,1920)", add
label define racedlbl 632 "Hawaiian and European (1900,1920)", add
label define racedlbl 634 "Hawaiian mixed", add
label define racedlbl 640 "Vietnamese", add
label define racedlbl 650 "Other Asian or Pacific Islander (1920,1980)", add
label define racedlbl 651 "Asian only (CPS)", add
label define racedlbl 652 "Pacific Islander only (CPS)", add
label define racedlbl 653 "Asian or Pacific Islander, n.s. (1990 Internal Census files)", add
label define racedlbl 660 "Cambodian", add
label define racedlbl 661 "Hmong", add
label define racedlbl 662 "Laotian", add
label define racedlbl 663 "Thai", add
label define racedlbl 664 "Bangladeshi", add
label define racedlbl 665 "Burmese", add
label define racedlbl 666 "Indonesian", add
label define racedlbl 667 "Malaysian", add
label define racedlbl 668 "Okinawan", add
label define racedlbl 669 "Pakistani", add
label define racedlbl 670 "Sri Lankan", add
label define racedlbl 671 "Other Asian, n.e.c.", add
label define racedlbl 672 "Asian, not specified", add
label define racedlbl 673 "Chinese and Japanese", add
label define racedlbl 674 "Chinese and Filipino", add
label define racedlbl 675 "Chinese and Vietnamese", add
label define racedlbl 676 "Chinese and Asian write-in", add
label define racedlbl 677 "Japanese and Filipino", add
label define racedlbl 678 "Asian Indian and Asian write-in", add
label define racedlbl 679 "Other Asian race combinations", add
label define racedlbl 680 "Samoan", add
label define racedlbl 681 "Tahitian", add
label define racedlbl 682 "Tongan", add
label define racedlbl 683 "Other Polynesian (1990)", add
label define racedlbl 684 "1+ other Polynesian races (2000,ACS)", add
label define racedlbl 685 "Guamanian/Chamorro", add
label define racedlbl 686 "Northern Mariana Islander", add
label define racedlbl 687 "Palauan", add
label define racedlbl 688 "Other Micronesian (1990)", add
label define racedlbl 689 "1+ other Micronesian races (2000,ACS)", add
label define racedlbl 690 "Fijian", add
label define racedlbl 691 "Other Melanesian (1990)", add
label define racedlbl 692 "1+ other Melanesian races (2000,ACS)", add
label define racedlbl 698 "2+ PI races from 2+ PI regions", add
label define racedlbl 699 "Pacific Islander, n.s.", add
label define racedlbl 700 "Other race, n.e.c.", add
label define racedlbl 801 "White and Black", add
label define racedlbl 802 "White and AIAN", add
label define racedlbl 810 "White and Asian", add
label define racedlbl 811 "White and Chinese", add
label define racedlbl 812 "White and Japanese", add
label define racedlbl 813 "White and Filipino", add
label define racedlbl 814 "White and Asian Indian", add
label define racedlbl 815 "White and Korean", add
label define racedlbl 816 "White and Vietnamese", add
label define racedlbl 817 "White and Asian write-in", add
label define racedlbl 818 "White and other Asian race(s)", add
label define racedlbl 819 "White and two or more Asian groups", add
label define racedlbl 820 "White and PI", add
label define racedlbl 821 "White and Native Hawaiian", add
label define racedlbl 822 "White and Samoan", add
label define racedlbl 823 "White and Guamanian", add
label define racedlbl 824 "White and PI write-in", add
label define racedlbl 825 "White and other PI race(s)", add
label define racedlbl 826 "White and other race write-in", add
label define racedlbl 830 "Black and AIAN", add
label define racedlbl 831 "Black and Asian", add
label define racedlbl 832 "Black and Chinese", add
label define racedlbl 833 "Black and Japanese", add
label define racedlbl 834 "Black and Filipino", add
label define racedlbl 835 "Black and Asian Indian", add
label define racedlbl 836 "Black and Korean", add
label define racedlbl 837 "Black and Asian write-in", add
label define racedlbl 838 "Black and other Asian race(s)", add
label define racedlbl 840 "Black and PI", add
label define racedlbl 841 "Black and PI write-in", add
label define racedlbl 842 "Black and other PI race(s)", add
label define racedlbl 845 "Black and other race write-in", add
label define racedlbl 850 "AIAN and Asian", add
label define racedlbl 851 "AIAN and Filipino (2000 1%)", add
label define racedlbl 852 "AIAN and Asian Indian", add
label define racedlbl 853 "AIAN and Asian write-in (2000 1%)", add
label define racedlbl 854 "AIAN and other Asian race(s)", add
label define racedlbl 855 "AIAN and PI", add
label define racedlbl 856 "AIAN and other race write-in", add
label define racedlbl 860 "Asian and PI", add
label define racedlbl 861 "Chinese and Hawaiian", add
label define racedlbl 862 "Chinese, Filipino, Hawaiian (2000 1%)", add
label define racedlbl 863 "Japanese and Hawaiian (2000 1%)", add
label define racedlbl 864 "Filipino and Hawaiian", add
label define racedlbl 865 "Filipino and PI write-in", add
label define racedlbl 866 "Asian Indian and PI write-in (2000 1%)", add
label define racedlbl 867 "Asian write-in and PI write-in", add
label define racedlbl 868 "Other Asian race(s) and PI race(s)", add
label define racedlbl 880 "Asian and other race write-in", add
label define racedlbl 881 "Chinese and other race write-in", add
label define racedlbl 882 "Japanese and other race write-in", add
label define racedlbl 883 "Filipino and other race write-in", add
label define racedlbl 884 "Asian Indian and other race write-in", add
label define racedlbl 885 "Asian write-in and other race write-in", add
label define racedlbl 886 "Other Asian race(s) and other race write-in", add
label define racedlbl 890 "PI and other race write-in:", add
label define racedlbl 891 "PI write-in and other race write-in", add
label define racedlbl 892 "Other PI race(s) and other race write-in", add
label define racedlbl 901 "White, Black, AIAN", add
label define racedlbl 902 "White, Black, Asian", add
label define racedlbl 903 "White, Black, PI", add
label define racedlbl 904 "White, Black, other race write-in", add
label define racedlbl 905 "White, AIAN, Asian", add
label define racedlbl 906 "White, AIAN, PI", add
label define racedlbl 907 "White, AIAN, other race write-in", add
label define racedlbl 910 "White, Asian, PI", add
label define racedlbl 911 "White, Chinese, Hawaiian", add
label define racedlbl 912 "White, Chinese, Filipino, Hawaiian (2000 1%)", add
label define racedlbl 913 "White, Japanese, Hawaiian (2000 1%)", add
label define racedlbl 914 "White, Filipino, Hawaiian", add
label define racedlbl 915 "Other White, Asian race(s), PI race(s)", add
label define racedlbl 920 "White, Asian, other race write-in", add
label define racedlbl 921 "White, Filipino, other race write-in (2000 1%)", add
label define racedlbl 922 "White, Asian write-in, other race write-in (2000 1%)", add
label define racedlbl 923 "Other White, Asian race(s), other race write-in (2000 1%)", add
label define racedlbl 925 "White, PI, other race write-in", add
label define racedlbl 930 "Black, AIAN, Asian", add
label define racedlbl 931 "Black, AIAN, PI", add
label define racedlbl 932 "Black, AIAN, other race write-in", add
label define racedlbl 933 "Black, Asian, PI", add
label define racedlbl 934 "Black, Asian, other race write-in", add
label define racedlbl 935 "Black, PI, other race write-in", add
label define racedlbl 940 "AIAN, Asian, PI", add
label define racedlbl 941 "AIAN, Asian, other race write-in", add
label define racedlbl 942 "AIAN, PI, other race write-in", add
label define racedlbl 943 "Asian, PI, other race write-in", add
label define racedlbl 949 "2 or 3 races (CPS)", add
label define racedlbl 950 "White, Black, AIAN, Asian", add
label define racedlbl 951 "White, Black, AIAN, PI", add
label define racedlbl 952 "White, Black, AIAN, other race write-in", add
label define racedlbl 953 "White, Black, Asian, PI", add
label define racedlbl 954 "White, Black, Asian, other race write-in", add
label define racedlbl 955 "White, Black, PI, other race write-in", add
label define racedlbl 960 "White, AIAN, Asian, PI", add
label define racedlbl 961 "White, AIAN, Asian, other race write-in", add
label define racedlbl 962 "White, AIAN, PI, other race write-in", add
label define racedlbl 963 "White, Asian, PI, other race write-in", add
label define racedlbl 970 "Black, AIAN, Asian, PI", add
label define racedlbl 971 "Black, AIAN, Asian, other race write-in", add
label define racedlbl 972 "Black, AIAN, PI, other race write-in", add
label define racedlbl 973 "Black, Asian, PI, other race write-in", add
label define racedlbl 974 "AIAN, Asian, PI, other race write-in", add
label define racedlbl 980 "White, Black, AIAN, Asian, PI", add
label define racedlbl 981 "White, Black, AIAN, Asian, other race write-in", add
label define racedlbl 982 "White, Black, AIAN, PI, other race write-in", add
label define racedlbl 983 "White, Black, Asian, PI, other race write-in", add
label define racedlbl 984 "White, AIAN, Asian, PI, other race write-in", add
label define racedlbl 985 "Black, AIAN, Asian, PI, other race write-in", add
label define racedlbl 989 "4 or 5 races (CPS)", add
label define racedlbl 990 "White, Black, AIAN, Asian, PI, other race write-in", add
label define racedlbl 996 "2+ races, n.e.c. (CPS)", add
label values raced racedlbl

label define bpllbl 001 "Alabama", add
label define bpllbl 002 "Alaska", add
label define bpllbl 004 "Arizona", add
label define bpllbl 005 "Arkansas", add
label define bpllbl 006 "California", add
label define bpllbl 008 "Colorado", add
label define bpllbl 009 "Connecticut", add
label define bpllbl 010 "Delaware", add
label define bpllbl 011 "District of Columbia", add
label define bpllbl 012 "Florida", add
label define bpllbl 013 "Georgia", add
label define bpllbl 015 "Hawaii", add
label define bpllbl 016 "Idaho", add
label define bpllbl 017 "Illinois", add
label define bpllbl 018 "Indiana", add
label define bpllbl 019 "Iowa", add
label define bpllbl 020 "Kansas", add
label define bpllbl 021 "Kentucky", add
label define bpllbl 022 "Louisiana", add
label define bpllbl 023 "Maine", add
label define bpllbl 024 "Maryland", add
label define bpllbl 025 "Massachusetts", add
label define bpllbl 026 "Michigan", add
label define bpllbl 027 "Minnesota", add
label define bpllbl 028 "Mississippi", add
label define bpllbl 029 "Missouri", add
label define bpllbl 030 "Montana", add
label define bpllbl 031 "Nebraska", add
label define bpllbl 032 "Nevada", add
label define bpllbl 033 "New Hampshire", add
label define bpllbl 034 "New Jersey", add
label define bpllbl 035 "New Mexico", add
label define bpllbl 036 "New York", add
label define bpllbl 037 "North Carolina", add
label define bpllbl 038 "North Dakota", add
label define bpllbl 039 "Ohio", add
label define bpllbl 040 "Oklahoma", add
label define bpllbl 041 "Oregon", add
label define bpllbl 042 "Pennsylvania", add
label define bpllbl 044 "Rhode Island", add
label define bpllbl 045 "South Carolina", add
label define bpllbl 046 "South Dakota", add
label define bpllbl 047 "Tennessee", add
label define bpllbl 048 "Texas", add
label define bpllbl 049 "Utah", add
label define bpllbl 050 "Vermont", add
label define bpllbl 051 "Virginia", add
label define bpllbl 053 "Washington", add
label define bpllbl 054 "West Virginia", add
label define bpllbl 055 "Wisconsin", add
label define bpllbl 056 "Wyoming", add
label define bpllbl 090 "Native American", add
label define bpllbl 099 "United States, ns", add
label define bpllbl 100 "American Samoa", add
label define bpllbl 105 "Guam", add
label define bpllbl 110 "Puerto Rico", add
label define bpllbl 115 "U.S. Virgin Islands", add
label define bpllbl 120 "Other US Possessions", add
label define bpllbl 150 "Canada", add
label define bpllbl 155 "St. Pierre and Miquelon", add
label define bpllbl 160 "Atlantic Islands", add
label define bpllbl 199 "North America, ns", add
label define bpllbl 200 "Mexico", add
label define bpllbl 210 "Central America", add
label define bpllbl 250 "Cuba", add
label define bpllbl 260 "West Indies", add
label define bpllbl 300 "SOUTH AMERICA", add
label define bpllbl 400 "Denmark", add
label define bpllbl 401 "Finland", add
label define bpllbl 402 "Iceland", add
label define bpllbl 403 "Lapland, n.s.", add
label define bpllbl 404 "Norway", add
label define bpllbl 405 "Sweden", add
label define bpllbl 410 "England", add
label define bpllbl 411 "Scotland", add
label define bpllbl 412 "Wales", add
label define bpllbl 413 "United Kingdom, ns", add
label define bpllbl 414 "Ireland", add
label define bpllbl 419 "Northern Europe, ns", add
label define bpllbl 420 "Belgium", add
label define bpllbl 421 "France", add
label define bpllbl 422 "Liechtenstein", add
label define bpllbl 423 "Luxembourg", add
label define bpllbl 424 "Monaco", add
label define bpllbl 425 "Netherlands", add
label define bpllbl 426 "Switerland", add
label define bpllbl 429 "Western Europe, ns", add
label define bpllbl 430 "Albania", add
label define bpllbl 431 "Andorra", add
label define bpllbl 432 "Gibraltar", add
label define bpllbl 433 "Greece", add
label define bpllbl 434 "Italy", add
label define bpllbl 435 "Malta", add
label define bpllbl 436 "Portugal", add
label define bpllbl 437 "San Marino", add
label define bpllbl 438 "Spain", add
label define bpllbl 439 "Vatican City", add
label define bpllbl 440 "Southern Europe, ns", add
label define bpllbl 450 "Austria", add
label define bpllbl 451 "Bulgaria", add
label define bpllbl 452 "Czechoslovakia", add
label define bpllbl 453 "Germany", add
label define bpllbl 454 "Hungary", add
label define bpllbl 455 "Poland", add
label define bpllbl 456 "Romania", add
label define bpllbl 457 "Yugoslavia", add
label define bpllbl 458 "Central Europe, ns", add
label define bpllbl 459 "Eastern Europe, ns", add
label define bpllbl 460 "Estonia", add
label define bpllbl 461 "Latvia", add
label define bpllbl 462 "Lithuania", add
label define bpllbl 463 "Baltic States, ns", add
label define bpllbl 465 "Other USSR/Russia", add
label define bpllbl 499 "Europe, ns", add
label define bpllbl 500 "China", add
label define bpllbl 501 "Japan", add
label define bpllbl 502 "Korea", add
label define bpllbl 509 "East Asia, ns", add
label define bpllbl 510 "Brunei", add
label define bpllbl 511 "Cambodia (Kampuchea)", add
label define bpllbl 512 "Indonesia", add
label define bpllbl 513 "Laos", add
label define bpllbl 514 "Malaysia", add
label define bpllbl 515 "Philippines", add
label define bpllbl 516 "Singapore", add
label define bpllbl 517 "Thailand", add
label define bpllbl 518 "Vietnam", add
label define bpllbl 519 "Southeast Asia, ns", add
label define bpllbl 520 "Afghanistan", add
label define bpllbl 521 "India", add
label define bpllbl 522 "Iran", add
label define bpllbl 523 "Maldives", add
label define bpllbl 524 "Nepal", add
label define bpllbl 530 "Bahrain", add
label define bpllbl 531 "Cyprus", add
label define bpllbl 532 "Iraq", add
label define bpllbl 533 "Iraq/Saudi Arabia", add
label define bpllbl 534 "Israel/Palestine", add
label define bpllbl 535 "Jordan", add
label define bpllbl 536 "Kuwait", add
label define bpllbl 537 "Lebanon", add
label define bpllbl 538 "Oman", add
label define bpllbl 539 "Qatar", add
label define bpllbl 540 "Saudi Arabia", add
label define bpllbl 541 "Syria", add
label define bpllbl 542 "Turkey", add
label define bpllbl 543 "United Arab Emirates", add
label define bpllbl 544 "Yemen Arab Republic (North)", add
label define bpllbl 545 "Yemen, PDR (South)", add
label define bpllbl 546 "Persian Gulf States, n.s.", add
label define bpllbl 547 "Middle East, ns", add
label define bpllbl 548 "Southwest Asia, nec/ns", add
label define bpllbl 549 "Asia Minor, ns", add
label define bpllbl 550 "South Asia, nec", add
label define bpllbl 599 "Asia, nec/ns", add
label define bpllbl 600 "AFRICA", add
label define bpllbl 700 "Australia and New Zealand", add
label define bpllbl 710 "Pacific Islands", add
label define bpllbl 800 "Antarctica, ns/nec", add
label define bpllbl 900 "Abroad (unknown) or at sea", add
label define bpllbl 950 "Other, nec", add
label values bpl bpllbl

label define hispanlbl 0 "Not Hispanic"
label define hispanlbl 1 "Mexican", add
label define hispanlbl 2 "Puerto Rican", add
label define hispanlbl 3 "Cuban", add
label define hispanlbl 4 "Other", add
label define hispanlbl 9 "Not Reported", add
label values hispan hispanlbl

label define educreclbl 0 "N/A  or No schooling"
label define educreclbl 1 "None or preschool", add
label define educreclbl 2 "Grade 1, 2, 3, or 4", add
label define educreclbl 3 "Grade 5, 6, 7, or 8", add
label define educreclbl 4 "Grade 9", add
label define educreclbl 5 "Grade 10", add
label define educreclbl 6 "Grade 11", add
label define educreclbl 7 "Grade 12", add
label define educreclbl 8 "1 to 3 years of college", add
label define educreclbl 9 "4+ years of college", add
label values educrec educreclbl

label define empstatdlbl 00 "N/A", add
label define empstatdlbl 10 "At work", add
label define empstatdlbl 11 "At work, public emerg", add
label define empstatdlbl 12 "Has job, not working", add
label define empstatdlbl 13 "Armed forces", add
label define empstatdlbl 14 "Armed forces--at work", add
label define empstatdlbl 15 "Armed forces--not at work but with job", add
label define empstatdlbl 20 "Unemployed", add
label define empstatdlbl 21 "Unemp, exper worker", add
label define empstatdlbl 22 "Unemp, new worker", add
label define empstatdlbl 30 "Not in Labor Force", add
label define empstatdlbl 31 "NILF, housework", add
label define empstatdlbl 32 "NILF, unable to work", add
label define empstatdlbl 33 "NILF, school", add
label define empstatdlbl 34 "NILF, other", add
label values empstatd empstatdlbl

label define migrate5lbl 0 "N/A", add
label define migrate5lbl 1 "Same house", add
label define migrate5lbl 2 "Place not reported", add
label define migrate5lbl 3 "Moved within county (in Puerto Rico, within municipio)", add
label define migrate5lbl 4 "Moved within state, between counties (in Puerto Rico, between municipios)", add
label define migrate5lbl 5 "Moved between states (or between Puerto Rico and a state)", add
label define migrate5lbl 6 "Abroad 5 years ago", add
label define migrate5lbl 7 "Same state (migration status within state unknown)", add
label define migrate5lbl 9 "Unknown", add
label values migrate5 migrate5lbl

label define migplac5lbl 000 "N/A", add
label define migplac5lbl 001 "Alabama", add
label define migplac5lbl 002 "Alaska", add
label define migplac5lbl 004 "Arizona", add
label define migplac5lbl 005 "Arkansas", add
label define migplac5lbl 006 "California", add
label define migplac5lbl 008 "Colorado", add
label define migplac5lbl 009 "Connecticut", add
label define migplac5lbl 010 "Delaware", add
label define migplac5lbl 011 "District of Columbia", add
label define migplac5lbl 012 "Florida", add
label define migplac5lbl 013 "Georgia", add
label define migplac5lbl 015 "Hawaii", add
label define migplac5lbl 016 "Idaho", add
label define migplac5lbl 017 "Illinois", add
label define migplac5lbl 018 "Indiana", add
label define migplac5lbl 019 "Iowa", add
label define migplac5lbl 020 "Kansas", add
label define migplac5lbl 021 "Kentucky", add
label define migplac5lbl 022 "Louisiana", add
label define migplac5lbl 023 "Maine", add
label define migplac5lbl 024 "Maryland", add
label define migplac5lbl 025 "Massachusetts", add
label define migplac5lbl 026 "Michigan", add
label define migplac5lbl 027 "Minnesota", add
label define migplac5lbl 028 "Mississippi", add
label define migplac5lbl 029 "Missouri", add
label define migplac5lbl 030 "Montana", add
label define migplac5lbl 031 "Nebraska", add
label define migplac5lbl 032 "Nevada", add
label define migplac5lbl 033 "New Hampshire", add
label define migplac5lbl 034 "New Jersey", add
label define migplac5lbl 035 "New Mexico", add
label define migplac5lbl 036 "New York", add
label define migplac5lbl 037 "North Carolina", add
label define migplac5lbl 038 "North Dakota", add
label define migplac5lbl 039 "Ohio", add
label define migplac5lbl 040 "Oklahoma", add
label define migplac5lbl 041 "Oregon", add
label define migplac5lbl 042 "Pennsylvania", add
label define migplac5lbl 044 "Rhode Island", add
label define migplac5lbl 045 "South Carolina", add
label define migplac5lbl 046 "South Dakota", add
label define migplac5lbl 047 "Tennessee", add
label define migplac5lbl 048 "Texas", add
label define migplac5lbl 049 "Utah", add
label define migplac5lbl 050 "Vermont", add
label define migplac5lbl 051 "Virginia", add
label define migplac5lbl 053 "Washington", add
label define migplac5lbl 054 "West Virginia", add
label define migplac5lbl 055 "Wisconsin", add
label define migplac5lbl 056 "Wyoming", add
label define migplac5lbl 061 "Maine-New Hampshire-Vermont", add
label define migplac5lbl 062 "Massachussetts-Rhode Island", add
label define migplac5lbl 063 "Minnesota-Iowa-Missouri-Kansas-Nebraska-Dakotas", add
label define migplac5lbl 064 "Maryland-Delaware", add
label define migplac5lbl 065 "Montana-Idaho-Wyoming", add
label define migplac5lbl 066 "Utah-Nevada", add
label define migplac5lbl 067 "Arizona-New Mexico", add
label define migplac5lbl 068 "Alaska-Hawaii", add
label define migplac5lbl 099 "United States, not specified or state confidential", add
label define migplac5lbl 100 "Samoa", add
label define migplac5lbl 105 "Guam", add
label define migplac5lbl 110 "Puerto Rico", add
label define migplac5lbl 115 "Virgin Islands", add
label define migplac5lbl 119 "US outlying area (1980)", add
label define migplac5lbl 120 "Other US Possessions", add
label define migplac5lbl 150 "Canada", add
label define migplac5lbl 151 "English Canada", add
label define migplac5lbl 152 "French Canada", add
label define migplac5lbl 155 "St Pierre and Miquelon", add
label define migplac5lbl 160 "Atlantic Islands", add
label define migplac5lbl 199 "North America", add
label define migplac5lbl 200 "Mexico", add
label define migplac5lbl 211 "Belize/British Honduras", add
label define migplac5lbl 212 "Costa Rica", add
label define migplac5lbl 213 "El Salvador", add
label define migplac5lbl 214 "Guatemala", add
label define migplac5lbl 215 "Honduras", add
label define migplac5lbl 216 "Nicaragua", add
label define migplac5lbl 217 "Panama", add
label define migplac5lbl 218 "Canal Zone", add
label define migplac5lbl 219 "Central America, nec", add
label define migplac5lbl 250 "Cuba", add
label define migplac5lbl 260 "West Indies", add
label define migplac5lbl 261 "Dominican Republic", add
label define migplac5lbl 262 "Haita", add
label define migplac5lbl 263 "Jamaica", add
label define migplac5lbl 264 "British West Indies", add
label define migplac5lbl 266 "Trinidad and Tobago", add
label define migplac5lbl 267 "Other West Indies", add
label define migplac5lbl 305 "Argentina", add
label define migplac5lbl 310 "Bolivia", add
label define migplac5lbl 315 "Brazil", add
label define migplac5lbl 320 "Chile", add
label define migplac5lbl 325 "Colombia", add
label define migplac5lbl 330 "Ecuador", add
label define migplac5lbl 345 "Paraguay", add
label define migplac5lbl 350 "Peru", add
label define migplac5lbl 360 "Uruguay", add
label define migplac5lbl 365 "Venezuela", add
label define migplac5lbl 370 "North or Central America, n.s. (2000 5%)", add
label define migplac5lbl 390 "South America, nec", add
label define migplac5lbl 400 "Denmark", add
label define migplac5lbl 401 "Finland", add
label define migplac5lbl 402 "Iceland", add
label define migplac5lbl 404 "Norway", add
label define migplac5lbl 405 "Sweden", add
label define migplac5lbl 410 "England", add
label define migplac5lbl 411 "Scotland", add
label define migplac5lbl 412 "Wales", add
label define migplac5lbl 413 "United Kingdom", add
label define migplac5lbl 414 "Ireland", add
label define migplac5lbl 415 "Northern Ireland", add
label define migplac5lbl 420 "Belgium", add
label define migplac5lbl 421 "France", add
label define migplac5lbl 422 "Liechtenstein", add
label define migplac5lbl 423 "Luxembourg", add
label define migplac5lbl 424 "Monaco", add
label define migplac5lbl 425 "Netherlands", add
label define migplac5lbl 426 "Switzerland", add
label define migplac5lbl 430 "Albania", add
label define migplac5lbl 431 "Andorra", add
label define migplac5lbl 432 "Gibraltar", add
label define migplac5lbl 433 "Greece", add
label define migplac5lbl 434 "Dodecanese Islands", add
label define migplac5lbl 435 "Italy", add
label define migplac5lbl 436 "Portugal", add
label define migplac5lbl 437 "Azores", add
label define migplac5lbl 438 "Spain", add
label define migplac5lbl 439 "Vatican City", add
label define migplac5lbl 440 "Malta", add
label define migplac5lbl 450 "Austria", add
label define migplac5lbl 451 "Bulgaria", add
label define migplac5lbl 452 "Czechoslovakia", add
label define migplac5lbl 453 "Germany", add
label define migplac5lbl 454 "Hungary", add
label define migplac5lbl 455 "Poland", add
label define migplac5lbl 456 "Romania", add
label define migplac5lbl 457 "Yugoslavia", add
label define migplac5lbl 460 "Estonia", add
label define migplac5lbl 461 "Latvia", add
label define migplac5lbl 462 "Lithuania", add
label define migplac5lbl 465 "USSR", add
label define migplac5lbl 496 "Byelorussia", add
label define migplac5lbl 498 "Ukraine", add
label define migplac5lbl 499 "Europe, n.s.", add
label define migplac5lbl 500 "China", add
label define migplac5lbl 501 "Japan", add
label define migplac5lbl 502 "Korea", add
label define migplac5lbl 510 "Brunei", add
label define migplac5lbl 511 "Cambodia", add
label define migplac5lbl 512 "Indonesia", add
label define migplac5lbl 513 "Laos", add
label define migplac5lbl 514 "Malaysia", add
label define migplac5lbl 515 "Philippines", add
label define migplac5lbl 516 "Singapore", add
label define migplac5lbl 517 "Thailand", add
label define migplac5lbl 518 "Vietnam", add
label define migplac5lbl 520 "Afghanistan", add
label define migplac5lbl 521 "India", add
label define migplac5lbl 522 "Iran", add
label define migplac5lbl 523 "Maldives", add
label define migplac5lbl 524 "Nepal", add
label define migplac5lbl 525 "Pakistan", add
label define migplac5lbl 530 "Bahrain", add
label define migplac5lbl 531 "Cyprus", add
label define migplac5lbl 532 "Iraq", add
label define migplac5lbl 534 "Israel", add
label define migplac5lbl 535 "Jordan", add
label define migplac5lbl 536 "Kuwait", add
label define migplac5lbl 537 "Lebanon", add
label define migplac5lbl 538 "Oman", add
label define migplac5lbl 539 "Qatar", add
label define migplac5lbl 540 "Saudi Arabia", add
label define migplac5lbl 541 "Syria", add
label define migplac5lbl 542 "Turkey", add
label define migplac5lbl 543 "United Arab Emirates", add
label define migplac5lbl 544 "Yemen", add
label define migplac5lbl 548 "Southwest Asia, nec/ns", add
label define migplac5lbl 599 "Asia, nec/ns", add
label define migplac5lbl 600 "Africa", add
label define migplac5lbl 610 "Northern Africa", add
label define migplac5lbl 612 "Egypt/United Arab Rep.", add
label define migplac5lbl 670 "Central Africa", add
label define migplac5lbl 690 "Southern Africa", add
label define migplac5lbl 694 "South Africa (Union of)", add
label define migplac5lbl 699 "Africa, nec", add
label define migplac5lbl 700 "Coral Sea Islands", add
label define migplac5lbl 701 "Australia", add
label define migplac5lbl 702 "New Zealand", add
label define migplac5lbl 710 "Pacific Islands", add
label define migplac5lbl 715 "US Pacific Trust Territories", add
label define migplac5lbl 800 "Heard and McDonald Islands", add
label define migplac5lbl 900 "Abroad (unknown) or at sea", add
label define migplac5lbl 911 "Abroad, ns", add
label define migplac5lbl 912 "At sea", add
label define migplac5lbl 990 "Same house", add
label define migplac5lbl 999 "Missing/unknown", add
label values migplac5 migplac5lbl

label values qage qagelbl

label values qmarst qmarstlbl

label values qrelate qrelatelbl

label values qsex qsexlbl

label values qbpl qbpllbl

label values qhispan qhispanlbl

label values qrace qracelbl

label values qeduc qeduclbl


*************************
* CRS VAR CODE 11/13/02 *
*************************


*generate the number of people in each metarea who
*are between the ages of 18 and 65 and who are not
*in the military

bysort metarea: gen metpop = _N
label var metpop "metarea sample N"

  **************************************
  * Weighted metpop variables 10/25/06 *
  **************************************

bysort metarea: egen metpopwt = sum(perwt)
label var metpopwt "total metpop"

bysort metarea: egen metpopwt_male = sum(perwt) if sex == 1
bysort metarea: egen metpopwt_fem = sum(perwt) if sex == 2

*male and female metpop variables on every record

bysort metarea: egen xmetpopwt_male = mean(metpopwt_male)
label var xmetpopwt_male "male metpop"

bysort metarea: egen xmetpopwt_fem = mean(metpopwt_fem)
label var xmetpopwt_fem "female metpop"




#delimit ;

*drop if in group quarters ;


    tab gq ;

    drop if gq == 3 | gq == 4 ;

    tab gq ;
    tab year ;
    tab year if age <= 78 ;


*Keep married people w/spouse present ;

    tab marst ;

    keep if marst == 1 ;


#delimit cr


gen spouse = (related == 201)
gen unmarp = (related == 1114)
gen hhead  = (related == 101)



tempfile first
save `first'


#delimit ;

*MATCH SPOUSES TO EACH OTHER.  This code is in Chapter
 5 of the IPUMS documentation "Family Interrelationships." ;

keep serial sploc datanum sex marst age hhead ;

rename sploc pernum ;


quietly for var sex marst age hhead: rename X sX ;

sort datanum serial pernum ;

tempfile spouse ;
save `spouse' ;

clear ;

set mem 2000m ;

use `first', clear ;


sort datanum serial pernum ;

merge datanum serial pernum using `spouse', unique ;


*Cases that don't have a spouse match ;

   tab marst _merge ;

   keep if _merge == 3 & marst == 1 ;
   drop _merge ;


keep serial pernum sex ssex age sage hhead shhead ;

*There are male and female records. Keep female records ;

keep if sex == 2 ;



*How many married couples are not in a couple where
 one of the partners is the household head? ;

 gen anyhhead = (hhead == 1 | shhead == 1) ;

 tab anyhhead if (age >= 20 & age <=34) & (sage >= 20 & sage <= 34) ;
 tab anyhhead if (age >= 20 & age <=49) & (sage >= 20 & sage <= 49) ;


 summarize age if anyhhead == 0 & (age >= 20 & age <=34) & (sage >= 20 & sage <= 34), detail ;
 summarize age if anyhhead == 1 & (age >= 20 & age <=34) & (sage >= 20 & sage <= 34), detail ;

 summarize age if anyhhead == 0 & (age >= 20 & age <=49) & (sage >= 20 & sage <= 49), detail ;
 summarize age if anyhhead == 1 & (age >= 20 & age <=49) & (sage >= 20 & sage <= 49), detail ;


